link_targets[2] = [
 ["(mod-path._.'2d/tabular.')", "../2d/index.html#%28mod-path._2d%2Ftabular%29"],
 ["(mod-path._.'2htdp/batch-io.')", "../teachpack/2htdpbatch-io.html"],
 ["(mod-path._.'2htdp/planetcute.')", "../teachpack/2htdpPlanet_Cute_Images.html"],
 ["(mod-path._.'2htdp/universe.')", "../teachpack/2htdpuniverse.html"],
 ["(mod-path._.'browser.')", "../browser/index.html#%28mod-path._browser%29"],
 ["(mod-path._.'compiler/cm.')", "../raco/API_for_Making_Bytecode.html"],
 ["(mod-path._.'compiler/decompile.')", "../raco/decompile.html#%28mod-path._compiler%2Fdecompile%29"],
 ["(mod-path._.'compiler/embed-unit.')", "../raco/exe.html#%28mod-path._compiler%2Fembed-unit%29"],
 ["(mod-path._.'compiler/find-exe.')", "../raco/exe.html#%28mod-path._compiler%2Ffind-exe%29"],
 ["(mod-path._.'compiler/module-suffix.')", "../raco/API_for_Raw_Compilation.html#%28mod-path._compiler%2Fmodule-suffix%29"],
 ["(mod-path._.'contract-profile.')", "../contract-profile/index.html"],
 ["(mod-path._.'db/util/cassandra.')", "../db/util.html#%28mod-path._db%2Futil%2Fcassandra%29"],
 ["(mod-path._.'drscheme/tool-lib.')", "../tools/index.html"],
 ["(mod-path._.'dynext/compile.')", "../dynext/Compilation.html"],
 ["(mod-path._.'dynext/file-unit.')", "../dynext/Filenames.html#%28mod-path._dynext%2Ffile-unit%29"],
 ["(mod-path._.'eopl.')", "../eopl/index.html"],
 ["(mod-path._.'ffi/objc.')", "../foreign/Objective-C_FFI.html#%28mod-path._ffi%2Fobjc%29"],
 ["(mod-path._.'ffi/unsafe.')", "../foreign/index.html"],
 ["(mod-path._.'ffi/unsafe/alloc.')", "../foreign/Allocation_and_Finalization.html"],
 ["(mod-path._.'ffi/unsafe/global.')", "../foreign/Process-Wide_Registration.html"],
 ["(mod-path._.'ffi/unsafe/try-atomic.')", "../foreign/Speculatively_Atomic_Execution.html"],
 ["(mod-path._.'file/gunzip.')", "../file/gunzip.html"],
 ["(mod-path._.'file/ico.')", "../file/ico.html"],
 ["(mod-path._.'file/sha1.')", "../file/sha1b.html"],
 ["(mod-path._.'file/zip.')", "../file/zip.html"],
 ["(mod-path._.'future-visualizer.')", "../future-visualizer/index.html"],
 ["(mod-path._.'htdp/guess-gui.')", "../teachpack/guess-gui.html"],
 ["(mod-path._.'htdp/guess.')", "../teachpack/guess.html"],
 ["(mod-path._.'images/compile-time.')", "../images/Embedding_Bitmaps_in_Compiled_Files.html"],
 ["(mod-path._.'images/icons/misc.')", "../images/Icons.html#%28mod-path._images%2Ficons%2Fmisc%29"],
 ["(mod-path._.'info.')", "../raco/info_rkt.html"],
 ["(mod-path._.'json.')", "../json/index.html"],
 ["(mod-path._.'lang/htdp-advanced.')", "../htdp/index.html#%28mod-path._lang%2Fhtdp-advanced%29"],
 ["(mod-path._.'lang/imageeq.')", "../htdp/index.html#%28mod-path._lang%2Fimageeq%29"],
 ["(mod-path._.'macro-debugger/stepper-text.')", "../macro-debugger/index.html#%28mod-path._macro-debugger%2Fstepper-text%29"],
 ["(mod-path._.'make.')", "../make/make.html"],
 ["(mod-path._.'math.')", "../math/index.html"],
 ["(mod-path._.'math/special-functions.')", "../math/special.html"],
 ["(mod-path._.'math/statistics.')", "../math/stats.html"],
 ["(mod-path._.'mred.')", "../scheme/mred.html"],
 ["(mod-path._.'mrlib/snip-canvas.')", "../mrlib/snip.html"],
 ["(mod-path._.'mzlib/awk.')", "../mzlib/mzlib_awk.html"],
 ["(mod-path._.'mzlib/compile.')", "../mzlib/mzlib_compile.html"],
 ["(mod-path._.'mzlib/inflate.')", "../mzlib/mzlib_inflate.html"],
 ["(mod-path._.'mzlib/pconvert.')", "../mzlib/mzlib_pconvert.html"],
 ["(mod-path._.'mzlib/process.')", "../mzlib/mzlib_process.html"],
 ["(mod-path._.'mzlib/shared.')", "../mzlib/mzlib_shared.html"],
 ["(mod-path._.'mzlib/tar.')", "../mzlib/mzlib_tar.html"],
 ["(mod-path._.'mzlib/trace.')", "../mzlib/mzlib_trace.html"],
 ["(mod-path._.'mzlib/transcr.')", "../mzlib/mzlib_transcr.html"],
 ["(mod-path._.'mzscheme.')", "../mzscheme/index.html"],
 ["(mod-path._.'net/cgi-unit.')", "../net/cgi.html#%28mod-path._net%2Fcgi-unit%29"],
 ["(mod-path._.'net/dns-unit.')", "../net/dns.html#%28mod-path._net%2Fdns-unit%29"],
 ["(mod-path._.'net/ftp-sig.')", "../net/ftp.html#%28mod-path._net%2Fftp-sig%29"],
 ["(mod-path._.'net/head-sig.')", "../net/head.html#%28mod-path._net%2Fhead-sig%29"],
 ["(mod-path._.'net/http-client.')", "../net/http-client.html"],
 ["(mod-path._.'net/imap-unit.')", "../net/imap.html#%28mod-path._net%2Fimap-unit%29"],
 ["(mod-path._.'net/nntp-sig.')", "../net/nntp.html#%28mod-path._net%2Fnntp-sig%29"],
 ["(mod-path._.'net/tcp-redirect.')", "../net/tcp-redirect.html"],
 ["(mod-path._.'net/uri-codec-unit.')", "../net/uri-codec.html#%28mod-path._net%2Furi-codec-unit%29"],
 ["(mod-path._.'net/url-connect.')", "../net/url.html#%28mod-path._net%2Furl-connect%29"],
 ["(mod-path._.'net/url-unit.')", "../net/url.html#%28mod-path._net%2Furl-unit%29"],
 ["(mod-path._.'openssl/sha1.')", "../openssl/index.html#%28mod-path._openssl%2Fsha1%29"],
 ["(mod-path._.'parser-tools/yacc.')", "../parser-tools/LALR_1__Parsers.html"],
 ["(mod-path._.'pict/code.')", "../pict/More_Pict_Constructors.html#%28mod-path._pict%2Fcode%29"],
 ["(mod-path._.'pict/tree-layout.')", "../pict/Tree_Layout.html"],
 ["(mod-path._.'pkg/name.')", "../pkg/name.html"],
 ["(mod-path._.'plai/collector.')", "../plai/collector.html"],
 ["(mod-path._.'plai/gc2/mutator.')", "../plai/gc2-mutator.html"],
 ["(mod-path._.'planet.')", "../planet/hash-lang-planet.html"],
 ["(mod-path._.'planet/syntax.')", "../planet/Utility_Libraries.html#%28mod-path._planet%2Fsyntax%29"],
 ["(mod-path._.'profile/render-text.')", "../profile/index.html#%28mod-path._profile%2Frender-text%29"],
 ["(mod-path._.'racket.')", "../reference/index.html"],
 ["(mod-path._.'racket/base.')", "../reference/index.html"],
 ["(mod-path._.'racket/block.')", "../reference/block.html"],
 ["(mod-path._.'racket/contract/parametric.')", "../reference/parametric-contracts.html"],
 ["(mod-path._.'racket/contract/region.')", "../reference/attaching-contracts-to-values.html#%28mod-path._racket%2Fcontract%2Fregion%29"],
 ["(mod-path._.'racket/draw/draw-sig.')", "../draw/Signature_and_Unit.html#%28mod-path._racket%2Fdraw%2Fdraw-sig%29"],
 ["(mod-path._.'racket/format.')", "../reference/strings.html#%28mod-path._racket%2Fformat%29"],
 ["(mod-path._.'racket/future.')", "../reference/futures.html"],
 ["(mod-path._.'racket/generic.')", "../reference/struct-generics.html"],
 ["(mod-path._.'racket/gui/dynamic.')", "../gui/Dynamic_Loading.html"],
 ["(mod-path._.'racket/kernel.')", "../reference/Kernel_Forms_and_Functions.html"],
 ["(mod-path._.'racket/language-info.')", "../reference/running-sa.html#%28mod-path._racket%2Flanguage-info%29"],
 ["(mod-path._.'racket/match.')", "../reference/match.html"],
 ["(mod-path._.'racket/mpair.')", "../compatibility/mlists.html#%28mod-path._racket%2Fmpair%29"],
 ["(mod-path._.'racket/path.')", "../reference/More_Path_Utilities.html"],
 ["(mod-path._.'racket/place.')", "../reference/places.html"],
 ["(mod-path._.'racket/port.')", "../reference/port-lib.html"],
 ["(mod-path._.'racket/promise.')", "../reference/Delayed_Evaluation.html"],
 ["(mod-path._.'racket/sandbox.')", "../reference/Sandboxed_Evaluation.html"],
 ["(mod-path._.'racket/sequence.')", "../reference/sequences.html#%28mod-path._racket%2Fsequence%29"],
 ["(mod-path._.'racket/string.')", "../reference/strings.html#%28mod-path._racket%2Fstring%29"],
 ["(mod-path._.'racket/struct.')", "../reference/structutils.html#%28mod-path._racket%2Fstruct%29"],
 ["(mod-path._.'racket/system.')", "../reference/subprocess.html#%28mod-path._racket%2Fsystem%29"],
 ["(mod-path._.'racket/tcp.')", "../reference/tcp.html"],
 ["(mod-path._.'racket/udp.')", "../reference/udp.html"],
 ["(mod-path._.'racket/unit-exptime.')", "../reference/Transformer_Helpers.html"],
 ["(mod-path._.'racket/unsafe/ops.')", "../reference/unsafe.html"],
 ["(mod-path._.'racket/vector.')", "../reference/vectors.html#%28mod-path._racket%2Fvector%29"],
 ["(mod-path._.'redex/gui.')", "../redex/The_Redex_Reference.html#%28mod-path._redex%2Fgui%29"],
 ["(mod-path._.'rnrs/files-6.')", "../r6rs/R6RS_Libraries.html#%28mod-path._rnrs%2Ffiles-6%29"],
 ["(mod-path._.'rnrs/io/ports-6.')", "../r6rs/R6RS_Libraries.html#%28mod-path._rnrs%2Fio%2Fports-6%29"],
 ["(mod-path._.'rnrs/lists-6.')", "../r6rs/R6RS_Libraries.html#%28mod-path._rnrs%2Flists-6%29"],
 ["(mod-path._.'rnrs/programs-6.')", "../r6rs/R6RS_Libraries.html#%28mod-path._rnrs%2Fprograms-6%29"],
 ["(mod-path._.'rnrs/records/inspection-6.')", "../r6rs/R6RS_Libraries.html#%28mod-path._rnrs%2Frecords%2Finspection-6%29"],
 ["(mod-path._.'scheme/cmdline.')", "../scheme/scheme_cmdline.html"],
 ["(mod-path._.'scheme/contract.')", "../scheme/scheme_contract.html"],
 ["(mod-path._.'scheme/dict.')", "../scheme/scheme_dict.html"],
 ["(mod-path._.'scheme/nest.')", "../scheme/nest.html"],
 ["(mod-path._.'scheme/require-transform.')", "../scheme/scheme_require-transform.html"],
 ["(mod-path._.'scribble/base.')", "../scribble/base.html"],
 ["(mod-path._.'scribble/core.')", "../scribble/core.html"],
 ["(mod-path._.'scribble/extract.')", "../scribble/srcdoc.html#%28mod-path._scribble%2Fextract%29"],
 ["(mod-path._.'scribble/html.')", "../scribble-pp/html.html"],
 ["(mod-path._.'scribble/lp-include.')", "../scribble/lp.html#%28mod-path._scribble%2Flp-include%29"],
 ["(mod-path._.'scribble/reader.')", "../scribble/reader-internals.html#%28mod-path._scribble%2Freader%29"],
 ["(mod-path._.'setup/cross-system.')", "../raco/cross-system.html"],
 ["(mod-path._.'setup/getinfo.')", "../raco/getinfo.html"],
 ["(mod-path._.'setup/path-to-relative.')", "../raco/relative-paths.html#%28mod-path._setup%2Fpath-to-relative%29"],
 ["(mod-path._.'setup/setup-unit.')", "../raco/setup-plt-plt.html#%28mod-path._setup%2Fsetup-unit%29"],
 ["(mod-path._.'setup/unpack.')", "../raco/unpack.html#%28mod-path._setup%2Funpack%29"],
 ["(mod-path._.'sgl.')", "../sgl/main.html"],
 ["(mod-path._.'sgl/bitmap.')", "../sgl/bitmaps.html"],
 ["(mod-path._.'slideshow.')", "../slideshow/index.html"],
 ["(mod-path._.'slideshow/text.')", "../slideshow/Text_Formatting_Helpers.html"],
 ["(mod-path._.'srfi/14.')", "../srfi/srfi-14.html"],
 ["(mod-path._.'srfi/23.')", "../srfi/srfi-23.html"],
 ["(mod-path._.'srfi/29.')", "../srfi/srfi-29.html"],
 ["(mod-path._.'srfi/38.')", "../srfi/srfi-38.html"],
 ["(mod-path._.'srfi/41.')", "../srfi/srfi-41.html"],
 ["(mod-path._.'srfi/74.')", "../srfi/srfi-74.html"],
 ["(mod-path._.'srfi/9.')", "../srfi/srfi-9.html"],
 ["(mod-path._.'srfi/98.')", "../srfi/srfi-98.html"],
 ["(mod-path._.'syntax-color/default-lexer.')", "../syntax-color/index.html#%28mod-path._syntax-color%2Fdefault-lexer%29"],
 ["(mod-path._.'syntax-color/token-tree.')", "../syntax-color/index.html#%28mod-path._syntax-color%2Ftoken-tree%29"],
 ["(mod-path._.'syntax/flatten-begin.')", "../syntax/transformer-helpers.html#%28mod-path._syntax%2Fflatten-begin%29"],
 ["(mod-path._.'syntax/id-set.')", "../syntax/syntax-helpers.html#%28mod-path._syntax%2Fid-set%29"],
 ["(mod-path._.'syntax/modresolve.')", "../syntax/module-helpers.html#%28mod-path._syntax%2Fmodresolve%29"],
 ["(mod-path._.'syntax/module-reader.')", "../syntax/reader-helpers.html#%28mod-path._syntax%2Fmodule-reader%29"],
 ["(mod-path._.'syntax/parse/experimental/eh.')", "../syntax/Experimental.html#%28mod-path._syntax%2Fparse%2Fexperimental%2Feh%29"],
 ["(mod-path._.'syntax/parse/experimental/reflect.')", "../syntax/Experimental.html#%28mod-path._syntax%2Fparse%2Fexperimental%2Freflect%29"],
 ["(mod-path._.'syntax/parse/experimental/splicing.')", "../syntax/Experimental.html#%28mod-path._syntax%2Fparse%2Fexperimental%2Fsplicing%29"],
 ["(mod-path._.'syntax/quote.')", "../syntax/Preserving_Source_Locations.html"],
 ["(mod-path._.'syntax/srcloc.')", "../syntax/Source_Locations.html#%28mod-path._syntax%2Fsrcloc%29"],
 ["(mod-path._.'syntax/strip-context.')", "../syntax/syntax-helpers.html#%28mod-path._syntax%2Fstrip-context%29"],
 ["(mod-path._.'typed/file/md5.')", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28mod-path._typed%2Ffile%2Fmd5%29"],
 ["(mod-path._.'typed/net/base64.')", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28mod-path._typed%2Fnet%2Fbase64%29"],
 ["(mod-path._.'typed/net/dns.')", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28mod-path._typed%2Fnet%2Fdns%29"],
 ["(mod-path._.'typed/net/gifwrite.')", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28mod-path._typed%2Fnet%2Fgifwrite%29"],
 ["(mod-path._.'typed/net/sendurl.')", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28mod-path._typed%2Fnet%2Fsendurl%29"],
 ["(mod-path._.'typed/net/uri-codec.')", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28mod-path._typed%2Fnet%2Furi-codec%29"],
 ["(mod-path._.'typed/net/url.')", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28mod-path._typed%2Fnet%2Furl%29"],
 ["(mod-path._.'typed/openssl/md5.')", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28mod-path._typed%2Fopenssl%2Fmd5%29"],
 ["(mod-path._.'typed/racket/async-channel.')", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28mod-path._typed%2Fracket%2Fasync-channel%29"],
 ["(mod-path._.'typed/racket/unsafe.')", "../ts-reference/Unsafe_Typed_Racket_operations.html"],
 ["(mod-path._.'typed/rackunit.')", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28mod-path._typed%2Frackunit%29"],
 ["(mod-path._.'typed/rackunit/gui.')", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28mod-path._typed%2Frackunit%2Fgui%29"],
 ["(mod-path._.'typed/scheme.')", "../ts-reference/Compatibility_Languages.html"],
 ["(mod-path._.'typed/scheme/base.')", "../ts-reference/Compatibility_Languages.html"],
 ["(mod-path._.'typed/syntax/stx.')", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28mod-path._typed%2Fsyntax%2Fstx%29"],
 ["(mod-path._.'web-server.')", "../web-server/stateless.html"],
 ["(mod-path._.'web-server/base.')", "../web-server/stateless.html"],
 ["(mod-path._.'web-server/dispatchers/dispatch-files.')", "../web-server-internal/dispatch-files.html"],
 ["(mod-path._.'web-server/dispatchers/dispatch-lift.')", "../web-server-internal/dispatch-lift.html"],
 ["(mod-path._.'web-server/dispatchers/filesystem-map.')", "../web-server-internal/filesystem-map.html"],
 ["(mod-path._.'web-server/formlets/input.')", "../web-server/formlets.html#%28mod-path._web-server%2Fformlets%2Finput%29"],
 ["(mod-path._.'web-server/http/id-cookie.')", "../web-server/http.html#%28mod-path._web-server%2Fhttp%2Fid-cookie%29"],
 ["(mod-path._.'web-server/http/request-structs.')", "../web-server/http.html#%28mod-path._web-server%2Fhttp%2Frequest-structs%29"],
 ["(mod-path._.'web-server/lang/file-box.')", "../web-server/stateless.html#%28mod-path._web-server%2Flang%2Ffile-box%29"],
 ["(mod-path._.'web-server/lang/web-cells.')", "../web-server/stateless.html#%28mod-path._web-server%2Flang%2Fweb-cells%29"],
 ["(mod-path._.'web-server/managers/timeouts.')", "../web-server/servlet.html#%28mod-path._web-server%2Fmanagers%2Ftimeouts%29"],
 ["(mod-path._.'web-server/page.')", "../web-server/page.html"],
 ["(mod-path._.'web-server/private/mod-map.')", "../web-server-internal/mod-map.html"],
 ["(mod-path._.'web-server/private/servlet.')", "../web-server-internal/dispatch-servlets.html#%28mod-path._web-server%2Fprivate%2Fservlet%29"],
 ["(mod-path._.'web-server/servlet-env.')", "../web-server/run.html#%28mod-path._web-server%2Fservlet-env%29"],
 ["(mod-path._.'web-server/servlet/setup.')", "../web-server-internal/dispatch-servlets.html#%28mod-path._web-server%2Fservlet%2Fsetup%29"],
 ["(mod-path._.'web-server/stuffers/gzip.')", "../web-server/stateless.html#%28mod-path._web-server%2Fstuffers%2Fgzip%29"],
 ["(mod-path._.'web-server/stuffers/hash.')", "../web-server/stateless.html#%28mod-path._web-server%2Fstuffers%2Fhash%29"],
 ["(mod-path._.'web-server/templates.')", "../web-server/templates.html"],
 ["(mod-path._.'web-server/web-server-unit.')", "../web-server-internal/Web_Servers.html#%28mod-path._web-server%2Fweb-server-unit%29"],
 ["(part._(.'(lib._2d/scribblings/2d..scrbl).'._.'2.D_.Direction_.Chars.'))", "../2d/index.html#%28part._2.D_.Direction_.Chars%29"],
 ["(part._(.'(lib._2d/scribblings/2d..scrbl).'._.'2.D_.Tabular.'))", "../2d/index.html#%28part._2.D_.Tabular%29"],
 ["(part._(.'(lib._browser/browser..scrbl).'._.'browser-unit.'))", "../browser/index.html#%28part._browser-unit%29"],
 ["(part._(.'(lib._browser/browser..scrbl).'._.'html-text.'))", "../browser/index.html#%28part._html-text%29"],
 ["(part._(.'(lib._compatibility/scribblings/compatibility..scrbl).'._.'.Legacy_.Racket_.Mutable_.List_.Library.'))", "../compatibility/mlists.html#%28part._.Legacy_.Racket_.Mutable_.List_.Library%29"],
 ["(part._(.'(lib._data/scribblings/data..scrbl).'._.'.More_.Enumeration_.Operations.'))", "../data/Enumerations.html#%28part._.More_.Enumeration_.Operations%29"],
 ["(part._(.'(lib._data/scribblings/data..scrbl).'._.'interval-map.'))", "../data/interval-map.html"],
 ["(part._(.'(lib._data/scribblings/data..scrbl).'._.'sec~3aenum-derived.'))", "../data/Enumerations.html#%28part._sec~3aenum-derived%29"],
 ["(part._(.'(lib._data/scribblings/data..scrbl).'._.'skip-list.'))", "../data/skip-list.html"],
 ["(part._(.'(lib._datalog/scribblings/datalog..scrbl).'._.'.Acknowledgments.'))", "../datalog/Acknowledgments.html"],
 ["(part._(.'(lib._db/scribblings/db..scrbl).'._.'.D.B2_.O.D.B.C_.Driver.'))", "../db/notes.html#%28part._.D.B2_.O.D.B.C_.Driver%29"],
 ["(part._(.'(lib._db/scribblings/db..scrbl).'._.'.S.Q.L_.N.U.L.L.'))", "../db/sql-types.html#%28part._.S.Q.L_.N.U.L.L%29"],
 ["(part._(.'(lib._db/scribblings/db..scrbl).'._.'.S.Q.L_.Server_.O.D.B.C_.Driver.'))", "../db/notes.html#%28part._.S.Q.L_.Server_.O.D.B.C_.Driver%29"],
 ["(part._(.'(lib._db/scribblings/db..scrbl).'._.'cassandra-types.'))", "../db/sql-types.html#%28part._cassandra-types%29"],
 ["(part._(.'(lib._db/scribblings/db..scrbl).'._.'datetime-util.'))", "../db/util.html#%28part._datetime-util%29"],
 ["(part._(.'(lib._db/scribblings/db..scrbl).'._.'dbperf-n+1.'))", "../db/using-db.html#%28part._dbperf-n%2B1%29"],
 ["(part._(.'(lib._db/scribblings/db..scrbl).'._.'dbperf-testing.'))", "../db/using-db.html#%28part._dbperf-testing%29"],
 ["(part._(.'(lib._db/scribblings/db..scrbl).'._.'dbperf-update-tx.'))", "../db/using-db.html#%28part._dbperf-update-tx%29"],
 ["(part._(.'(lib._db/scribblings/db..scrbl).'._.'geometry.'))", "../db/util.html#%28part._geometry%29"],
 ["(part._(.'(lib._db/scribblings/db..scrbl).'._.'kill-safe.'))", "../db/connect.html#%28part._kill-safe%29"],
 ["(part._(.'(lib._db/scribblings/db..scrbl).'._.'odbc-types.'))", "../db/sql-types.html#%28part._odbc-types%29"],
 ["(part._(.'(lib._db/scribblings/db..scrbl).'._.'postgresql-timestamp-tz.'))", "../db/notes.html#%28part._postgresql-timestamp-tz%29"],
 ["(part._(.'(lib._db/scribblings/db..scrbl).'._.'sqlite-types.'))", "../db/sql-types.html#%28part._sqlite-types%29"],
 ["(part._(.'(lib._deinprogramm/scribblings/deinprogramm..scrbl).'._.'.Bilder.'))", "../deinprogramm/image.html#%28part._.Bilder%29"],
 ["(part._(.'(lib._deinprogramm/scribblings/deinprogramm..scrbl).'._.'.Prozeduren.'))", "../deinprogramm/turtle.html#%28part._.Prozeduren%29"],
 ["(part._(.'(lib._deinprogramm/scribblings/deinprogramm..scrbl).'._.'.Testf_lle.'))", "../deinprogramm/Testf_lle.html"],
 ["(part._(.'(lib._deinprogramm/scribblings/deinprogramm..scrbl).'._.'.Tutorial.'))", "../deinprogramm/turtle.html#%28part._.Tutorial%29"],
 ["(part._(.'(lib._deinprogramm/scribblings/deinprogramm..scrbl).'._.'assignments-signatures.'))", "../deinprogramm/assignments-signatures.html"],
 ["(part._(.'(lib._deinprogramm/scribblings/deinprogramm..scrbl).'._.'composition.'))", "../deinprogramm/image.html#%28part._composition%29"],
 ["(part._(.'(lib._deinprogramm/scribblings/deinprogramm..scrbl).'._.'cond.'))", "../deinprogramm/cond.html"],
 ["(part._(.'(lib._deinprogramm/scribblings/deinprogramm..scrbl).'._.'list-of.'))", "../deinprogramm/signatures-vanilla.html#%28part._list-of%29"],
 ["(part._(.'(lib._deinprogramm/scribblings/deinprogramm..scrbl).'._.'one-of.'))", "../deinprogramm/Signaturen.html#%28part._one-of%29"],
 ["(part._(.'(lib._deinprogramm/scribblings/deinprogramm..scrbl).'._.'rendering.'))", "../deinprogramm/line3d.html#%28part._rendering%29"],
 ["(part._(.'(lib._dynext/dynext..scrbl).'._.'file-unit.'))", "../dynext/Filenames.html#%28part._file-unit%29"],
 ["(part._(.'(lib._dynext/dynext..scrbl).'._.'top.'))", "../dynext/index.html"],
 ["(part._(.'(lib._embedded-gui/scribblings/embedded-gui..scrbl).'._.'controls.'))", "../embedded-gui/controls.html"],
 ["(part._(.'(lib._embedded-gui/scribblings/embedded-gui..scrbl).'._.'embedded-text-button_.'))", "../embedded-gui/embedded-text-button_.html"],
 ["(part._(.'(lib._errortrace/scribblings/errortrace..scrbl).'._.'coverage.'))", "../errortrace/using-errortrace.html#%28part._coverage%29"],
 ["(part._(.'(lib._file/scribblings/file..scrbl).'._.'cache.'))", "../file/cache.html"],
 ["(part._(.'(lib._file/scribblings/file..scrbl).'._.'gzip.'))", "../file/gzip.html"],
 ["(part._(.'(lib._file/scribblings/file..scrbl).'._.'unzip.'))", "../file/unzip.html"],
 ["(part._(.'(lib._games/cards/cards..scrbl).'._.'.Cards__.Virtual_.Playing_.Cards_.Library.'))", "../cards/index.html"],
 ["(part._(.'(lib._games/cards/cards..scrbl).'._.'.Creating_.Tables_and_.Cards.'))", "../cards/index.html#%28part._.Creating_.Tables_and_.Cards%29"],
 ["(part._(.'(lib._games/cards/cards..scrbl).'._.'.Regions_and_.Buttons.'))", "../cards/index.html#%28part._.Regions_and_.Buttons%29"],
 ["(part._(.'(lib._games/cards/cards..scrbl).'._.'.Table_.Methods.'))", "../cards/index.html#%28part._.Table_.Methods%29"],
 ["(part._(.'(lib._games/cards/cards..scrbl).'._.'top.'))", "../cards/index.html"],
 ["(part._(.'(lib._games/gl-board-game/gl-board-game..scrbl).'._.'top.'))", "../gl-board-game/index.html"],
 ["(part._(.'(lib._games/scribblings/games..scrbl).'._.'.Auto-.Play.'))", "../games/gobblet.html#%28part._.Auto-.Play%29"],
 ["(part._(.'(lib._games/scribblings/games..scrbl).'._.'.Breadth-first_.Search.'))", "../games/Breadth-first_Search.html"],
 ["(part._(.'(lib._games/scribblings/games..scrbl).'._.'.Game_.Rules.'))", "../games/gobblet.html#%28part._.Game_.Rules%29"],
 ["(part._(.'(lib._games/scribblings/games..scrbl).'._.'bundled.'))", "../games/bundled.html"],
 ["(part._(.'(lib._games/scribblings/games..scrbl).'._.'gcalc.'))", "../games/gcalc.html"],
 ["(part._(.'(lib._games/scribblings/games..scrbl).'._.'ginrummy.'))", "../games/ginrummy.html"],
 ["(part._(.'(lib._games/scribblings/games..scrbl).'._.'gofish.'))", "../games/gofish.html"],
 ["(part._(.'(lib._games/scribblings/games..scrbl).'._.'lights-out.'))", "../games/lights-out.html"],
 ["(part._(.'(lib._games/scribblings/games..scrbl).'._.'new-games.'))", "../games/new-games.html"],
 ["(part._(.'(lib._graphics/scribblings/graphics..scrbl).'._.'.Graphics__.Legacy_.Library.'))", "../graphics/index.html"],
 ["(part._(.'(lib._graphics/scribblings/graphics..scrbl).'._.'.Protecting_.Graphics_.Operations.'))", "../graphics/Protecting_Graphics_Operations.html"],
 ["(part._(.'(lib._graphics/scribblings/graphics..scrbl).'._.'.Rectangles.'))", "../graphics/Draw__Clear__and_Flip_Operations.html#%28part._.Rectangles%29"],
 ["(part._(.'(lib._graphics/scribblings/graphics..scrbl).'._.'.Strings.'))", "../graphics/Draw__Clear__and_Flip_Operations.html#%28part._.Strings%29"],
 ["(part._(.'(lib._help/bug-report..scrbl).'._.'.Bug_.Reporting.'))", "../bug-report/index.html"],
 ["(part._(.'(lib._help/help..scrbl).'._.'.Help_and_.Documentation_.Utilities.'))", "../help/index.html"],
 ["(part._(.'(lib._htdp/htdp..scrbl).'._.'.Color_and_.Alpha_.Color_.Structs.'))", "../htdp/index.html#%28part._.Color_and_.Alpha_.Color_.Structs%29"],
 ["(part._(.'(lib._htdp/htdp..scrbl).'._.'.General_.Vocabulary_.Guidelines.'))", "../htdp/index.html#%28part._.General_.Vocabulary_.Guidelines%29"],
 ["(part._(.'(lib._htdp/htdp..scrbl).'._.'.Ht.D.P_.Advanced_.Student.'))", "../htdp/index.html#%28part._.Ht.D.P_.Advanced_.Student%29"],
 ["(part._(.'(lib._htdp/htdp..scrbl).'._.'error-reporting.'))", "../htdp/index.html#%28part._error-reporting%29"],
 ["(part._(.'(lib._html/html..scrbl).'._.'.H.T.M.L__.Parsing_.Library.'))", "../html/index.html"],
 ["(part._(.'(lib._images/scribblings/images..scrbl).'._.'.Compositing.'))", "../images/Compositing.html"],
 ["(part._(.'(lib._images/scribblings/images..scrbl).'._.'.Effects.'))", "../images/Effects.html"],
 ["(part._(.'(lib._images/scribblings/images..scrbl).'._.'.Logos.'))", "../images/Logos.html"],
 ["(part._(.'(lib._images/scribblings/images..scrbl).'._.'file.'))", "../images/Icons.html#%28part._file%29"],
 ["(part._(.'(lib._images/scribblings/images..scrbl).'._.'flomap~3aopacity.'))", "../images/Overview.html#%28part._flomap~3aopacity%29"],
 ["(part._(.'(lib._images/scribblings/images..scrbl).'._.'symbol.'))", "../images/Icons.html#%28part._symbol%29"],
 ["(part._(.'(lib._lazy/lazy..scrbl).'._.'top.'))", "../lazy/index.html"],
 ["(part._(.'(lib._macro-debugger/macro-debugger..scrbl).'._.'.Macro_.Debugger__.Inspecting_.Macro_.Expansion.'))", "../macro-debugger/index.html"],
 ["(part._(.'(lib._macro-debugger/macro-debugger..scrbl).'._.'.Primary_.Partition.'))", "../macro-debugger/index.html#%28part._.Primary_.Partition%29"],
 ["(part._(.'(lib._macro-debugger/macro-debugger..scrbl).'._.'.Properties.'))", "../macro-debugger/index.html#%28part._.Properties%29"],
 ["(part._(.'(lib._macro-debugger/macro-debugger..scrbl).'._.'.Secondary_.Partitioning.'))", "../macro-debugger/index.html#%28part._.Secondary_.Partitioning%29"],
 ["(part._(.'(lib._macro-debugger/macro-debugger..scrbl).'._.'.Using_the_.Syntax_.Browser.'))", "../macro-debugger/index.html#%28part._.Using_the_.Syntax_.Browser%29"],
 ["(part._(.'(lib._math/scribblings/math..scrbl).'._.'.Axis_.Folds.'))", "../math/array_fold.html#%28part._.Axis_.Folds%29"],
 ["(part._(.'(lib._math/scribblings/math..scrbl).'._.'.Correlation.'))", "../math/stats.html#%28part._.Correlation%29"],
 ["(part._(.'(lib._math/scribblings/math..scrbl).'._.'.Double-.Double_.Operations.'))", "../math/flonum.html#%28part._.Double-.Double_.Operations%29"],
 ["(part._(.'(lib._math/scribblings/math..scrbl).'._.'.Integer__remove_an_axis.'))", "../math/array_slicing.html#%28part._.Integer__remove_an_axis%29"],
 ["(part._(.'(lib._math/scribblings/math..scrbl).'._.'.Low-.Level_.Double-.Double_.Operations.'))", "../math/flonum.html#%28part._.Low-.Level_.Double-.Double_.Operations%29"],
 ["(part._(.'(lib._math/scribblings/math..scrbl).'._.'.Measuring_.Floating-.Point_.Error.'))", "../math/flonum.html#%28part._.Measuring_.Floating-.Point_.Error%29"],
 ["(part._(.'(lib._math/scribblings/math..scrbl).'._.'.Parameters.'))", "../math/bigfloat.html#%28part._.Parameters%29"],
 ["(part._(.'(lib._math/scribblings/math..scrbl).'._.'.Polygonal_.Numbers.'))", "../math/number-theory.html#%28part._.Polygonal_.Numbers%29"],
 ["(part._(.'(lib._math/scribblings/math..scrbl).'._.'.Slice-.Dots__preserve_remaining_axes.'))", "../math/array_slicing.html#%28part._.Slice-.Dots__preserve_remaining_axes%29"],
 ["(part._(.'(lib._math/scribblings/math..scrbl).'._.'array~3astrict.'))", "../math/array_strict.html"],
 ["(part._(.'(lib._math/scribblings/math..scrbl).'._.'matrix~3abroadcasting.'))", "../math/matrix_intro.html#%28part._matrix~3abroadcasting%29"],
 ["(part._(.'(lib._math/scribblings/math..scrbl).'._.'matrix~3aortho-alg.'))", "../math/matrix_ortho-alg.html"],
 ["(part._(.'(lib._math/scribblings/math..scrbl).'._.'matrix~3asolve.'))", "../math/matrix_solve.html"],
 ["(part._(.'(lib._math/scribblings/math..scrbl).'._.'matrix~3atypes.'))", "../math/matrix_types.html"],
 ["(part._(.'(lib._math/scribblings/math..scrbl).'._.'number-sequences.'))", "../math/number-theory.html#%28part._number-sequences%29"],
 ["(part._(.'(lib._math/scribblings/math..scrbl).'._.'ops.'))", "../math/bigfloat.html#%28part._ops%29"],
 ["(part._(.'(lib._math/scribblings/math..scrbl).'._.'predicates.'))", "../math/bigfloat.html#%28part._predicates%29"],
 ["(part._(.'(lib._math/scribblings/math..scrbl).'._.'stats~3arunning.'))", "../math/stats.html#%28part._stats~3arunning%29"],
 ["(part._(.'(lib._mrlib/scribblings/mrlib..scrbl).'._.'.Aligned_.Pasteboard.'))", "../mrlib/Aligned_Pasteboard.html"],
 ["(part._(.'(lib._mrlib/scribblings/mrlib..scrbl).'._.'.Hierarchical_.List_.Control.'))", "../mrlib/Hierarchical_List_Control.html"],
 ["(part._(.'(lib._mrlib/scribblings/mrlib..scrbl).'._.'.Interactive_.Value_.Port.'))", "../mrlib/Interactive_Value_Port.html"],
 ["(part._(.'(lib._mrlib/scribblings/mrlib..scrbl).'._.'.Matrix_.Snip.'))", "../mrlib/Matrix_Snip.html"],
 ["(part._(.'(lib._mrlib/scribblings/mrlib..scrbl).'._.'.Syntax_.Browser.'))", "../mrlib/Syntax_Browser.html"],
 ["(part._(.'(lib._mrlib/scribblings/mrlib..scrbl).'._.'.Te.X_.Table.'))", "../mrlib/TeX_Table.html"],
 ["(part._(.'(lib._mrlib/scribblings/mrlib..scrbl).'._.'aligned-editor-snip_.'))", "../mrlib/aligned-editor-snip_.html"],
 ["(part._(.'(lib._mysterx/scribblings/mysterx..scrbl).'._.'version.'))", "../mysterx/version.html"],
 ["(part._(.'(lib._mzcom/mzcom..scrbl).'._.'.Errors.'))", "../mzcom/index.html#%28part._.Errors%29"],
 ["(part._(.'(lib._mzcom/mzcom..scrbl).'._.'.Mz.C.O.M__.Racket_as_a_.Windows_.C.O.M_.Object.'))", "../mzcom/index.html"],
 ["(part._(.'(lib._mzcom/mzcom..scrbl).'._.'top.'))", "../mzcom/index.html"],
 ["(part._(.'(lib._mzlib/scribblings/mzlib..scrbl).'._.'.Rest_and_.Rest-like_.Arguments.'))", "../mzlib/mzlib_kw.html#%28part._.Rest_and_.Rest-like_.Arguments%29"],
 ["(part._(.'(lib._mzlib/scribblings/mzlib..scrbl).'._.'mzlib_compile.'))", "../mzlib/mzlib_compile.html"],
 ["(part._(.'(lib._mzlib/scribblings/mzlib..scrbl).'._.'mzlib_defmacro.'))", "../mzlib/mzlib_defmacro.html"],
 ["(part._(.'(lib._mzlib/scribblings/mzlib..scrbl).'._.'mzlib_for.'))", "../mzlib/mzlib_for.html"],
 ["(part._(.'(lib._mzlib/scribblings/mzlib..scrbl).'._.'mzlib_match.'))", "../mzlib/mzlib_match.html"],
 ["(part._(.'(lib._mzlib/scribblings/mzlib..scrbl).'._.'mzlib_process.'))", "../mzlib/mzlib_process.html"],
 ["(part._(.'(lib._mzlib/scribblings/mzlib..scrbl).'._.'mzlib_restart.'))", "../mzlib/mzlib_restart.html"],
 ["(part._(.'(lib._mzlib/scribblings/mzlib..scrbl).'._.'mzlib_shared.'))", "../mzlib/mzlib_shared.html"],
 ["(part._(.'(lib._mzlib/scribblings/mzlib..scrbl).'._.'mzlib_trace.'))", "../mzlib/mzlib_trace.html"],
 ["(part._(.'(lib._mzlib/scribblings/mzlib..scrbl).'._.'mzlib_unit-exptime.'))", "../mzlib/mzlib_unit-exptime.html"],
 ["(part._(.'(lib._mzlib/scribblings/mzlib..scrbl).'._.'mzlib_zip.'))", "../mzlib/mzlib_zip.html"],
 ["(part._(.'(lib._net/scribblings/net..scrbl).'._.'.Connecting_and_.Selecting_.Mailboxes.'))", "../net/imap.html#%28part._.Connecting_and_.Selecting_.Mailboxes%29"],
 ["(part._(.'(lib._net/scribblings/net..scrbl).'._.'.Exceptions.'))", "../net/nntp.html#%28part._.Exceptions%29"],
 ["(part._(.'(lib._net/scribblings/net..scrbl).'._.'.Header_.Signature.'))", "../net/head.html#%28part._.Header_.Signature%29"],
 ["(part._(.'(lib._net/scribblings/net..scrbl).'._.'.S.M.T.P_.Functions.'))", "../net/smtp.html#%28part._.S.M.T.P_.Functions%29"],
 ["(part._(.'(lib._net/scribblings/net..scrbl).'._.'.Sendmail_.Unit.'))", "../net/sendmail.html#%28part._.Sendmail_.Unit%29"],
 ["(part._(.'(lib._net/scribblings/net..scrbl).'._.'.U.R.I_.Codec_.Signature.'))", "../net/uri-codec.html#%28part._.U.R.I_.Codec_.Signature%29"],
 ["(part._(.'(lib._net/scribblings/net..scrbl).'._.'.U.R.I_.Codec_.Unit.'))", "../net/uri-codec.html#%28part._.U.R.I_.Codec_.Unit%29"],
 ["(part._(.'(lib._net/scribblings/net..scrbl).'._.'.U.R.L_.Unit.'))", "../net/url.html#%28part._.U.R.L_.Unit%29"],
 ["(part._(.'(lib._net/scribblings/net..scrbl).'._.'cookie-examples.'))", "../net/cookie.html#%28part._cookie-examples%29"],
 ["(part._(.'(lib._net/scribblings/net..scrbl).'._.'cookie.'))", "../net/cookie.html"],
 ["(part._(.'(lib._net/scribblings/net..scrbl).'._.'ftp.'))", "../net/ftp.html"],
 ["(part._(.'(lib._net/scribblings/net..scrbl).'._.'head.'))", "../net/head.html"],
 ["(part._(.'(lib._net/scribblings/net..scrbl).'._.'mime.'))", "../net/mime.html"],
 ["(part._(.'(lib._net/scribblings/net..scrbl).'._.'nntp.'))", "../net/nntp.html"],
 ["(part._(.'(lib._net/scribblings/net..scrbl).'._.'tcp-redirect.'))", "../net/tcp-redirect.html"],
 ["(part._(.'(lib._net/scribblings/net..scrbl).'._.'unihead.'))", "../net/unihead.html"],
 ["(part._(.'(lib._net/scribblings/net..scrbl).'._.'uri-codec-proc.'))", "../net/uri-codec.html#%28part._uri-codec-proc%29"],
 ["(part._(.'(lib._openssl/openssl..scrbl).'._.'.S.H.A-1_.Hashing.'))", "../openssl/index.html#%28part._.S.H.A-1_.Hashing%29"],
 ["(part._(.'(lib._optimization-coach/scribblings/optimization-coach..scrbl).'._.'.Refining_.Recommendations_with_.Profiling_.Information.'))", "../optimization-coach/index.html#%28part._.Refining_.Recommendations_with_.Profiling_.Information%29"],
 ["(part._(.'(lib._optimization-coach/scribblings/optimization-coach..scrbl).'._.'.Verbose_.Mode.'))", "../optimization-coach/index.html#%28part._.Verbose_.Mode%29"],
 ["(part._(.'(lib._parser-tools/parser-tools..scrbl).'._.'.Context-.Free_.Parsers.'))", "../parser-tools/Context-Free_Parsers.html"],
 ["(part._(.'(lib._parser-tools/parser-tools..scrbl).'._.'.L.A.L.R_1__.Parsers.'))", "../parser-tools/LALR_1__Parsers.html"],
 ["(part._(.'(lib._parser-tools/parser-tools..scrbl).'._.'.Lexers.'))", "../parser-tools/Lexers.html"],
 ["(part._(.'(lib._pict/scribblings/pict..scrbl).'._.'.Balloon_.Annotations.'))", "../pict/More_Pict_Constructors.html#%28part._.Balloon_.Annotations%29"],
 ["(part._(.'(lib._pict/scribblings/pict..scrbl).'._.'.Flash.'))", "../pict/More_Pict_Constructors.html#%28part._.Flash%29"],
 ["(part._(.'(lib._pict/scribblings/pict..scrbl).'._.'.Miscellaneous.'))", "../pict/Miscellaneous.html"],
 ["(part._(.'(lib._pict/scribblings/pict..scrbl).'._.'.More_.Pict_.Constructors.'))", "../pict/More_Pict_Constructors.html"],
 ["(part._(.'(lib._pict/scribblings/pict..scrbl).'._.'.Pict_.Finders.'))", "../pict/Pict_Finders.html"],
 ["(part._(.'(lib._picturing-programs/picturing-programs..scrbl).'._.'.About_.This_.Teachpack.'))", "../picturing-programs/index.html#%28part._.About_.This_.Teachpack%29"],
 ["(part._(.'(lib._picturing-programs/picturing-programs..scrbl).'._.'.Variables.'))", "../picturing-programs/index.html#%28part._.Variables%29"],
 ["(part._(.'(lib._picturing-programs/picturing-programs..scrbl).'._.'top.'))", "../picturing-programs/index.html"],
 ["(part._(.'(lib._pkg/scribblings/pkg..scrbl).'._.'.Functions_for_raco_pkg.'))", "../pkg/Functions_for_raco_pkg.html"],
 ["(part._(.'(lib._pkg/scribblings/pkg..scrbl).'._.'.Future_.Plans.'))", "../pkg/Future_Plans.html"],
 ["(part._(.'(lib._pkg/scribblings/pkg..scrbl).'._.'.How_can_.I_install_a_package_without_its_documentation_.'))", "../pkg/FAQ.html#%28part._.How_can_.I_install_a_package_without_its_documentation_%29"],
 ["(part._(.'(lib._pkg/scribblings/pkg..scrbl).'._.'.Interactions_.Between_git_and_raco_pkg.'))", "../pkg/git-workflow.html#%28part._.Interactions_.Between_git_and_raco_pkg%29"],
 ["(part._(.'(lib._pkg/scribblings/pkg..scrbl).'._.'clone-link.'))", "../pkg/git-workflow.html#%28part._clone-link%29"],
 ["(part._(.'(lib._pkg/scribblings/pkg..scrbl).'._.'concept~3amulti-collection.'))", "../pkg/Package_Concepts.html#%28part._concept~3amulti-collection%29"],
 ["(part._(.'(lib._pkg/scribblings/pkg..scrbl).'._.'git-workflow.'))", "../pkg/git-workflow.html"],
 ["(part._(.'(lib._pkg/scribblings/pkg..scrbl).'._.'manual-creation.'))", "../pkg/getting-started.html#%28part._manual-creation%29"],
 ["(part._(.'(lib._pkg/scribblings/pkg..scrbl).'._.'raco-pkg-catalog-copy.'))", "../pkg/cmdline.html#%28part._raco-pkg-catalog-copy%29"],
 ["(part._(.'(lib._pkg/scribblings/pkg..scrbl).'._.'raco-pkg-catalog-show.'))", "../pkg/cmdline.html#%28part._raco-pkg-catalog-show%29"],
 ["(part._(.'(lib._pkg/scribblings/pkg..scrbl).'._.'raco-pkg-install.'))", "../pkg/cmdline.html#%28part._raco-pkg-install%29"],
 ["(part._(.'(lib._pkg/scribblings/pkg..scrbl).'._.'raco-pkg-migrate.'))", "../pkg/cmdline.html#%28part._raco-pkg-migrate%29"],
 ["(part._(.'(lib._pkg/scribblings/pkg..scrbl).'._.'raco-pkg-show.'))", "../pkg/cmdline.html#%28part._raco-pkg-show%29"],
 ["(part._(.'(lib._pkg/scribblings/pkg..scrbl).'._.'raco-pkg-update.'))", "../pkg/cmdline.html#%28part._raco-pkg-update%29"],
 ["(part._(.'(lib._pkg/scribblings/pkg..scrbl).'._.'working-new-pkgs.'))", "../pkg/getting-started.html#%28part._working-new-pkgs%29"],
 ["(part._(.'(lib._plai/scribblings/plai..scrbl).'._.'.Building_.Mutators.'))", "../plai/mutator.html#%28part._.Building_.Mutators%29"],
 ["(part._(.'(lib._plai/scribblings/plai..scrbl).'._.'.Garbage_.Collector_.Interface_for_.G.C2.'))", "../plai/gc2-collector.html#%28part._.Garbage_.Collector_.Interface_for_.G.C2%29"],
 ["(part._(.'(lib._plai/scribblings/plai..scrbl).'._.'.Test_.Flags.'))", "../plai/plai-scheme.html#%28part._.Test_.Flags%29"],
 ["(part._(.'(lib._plai/scribblings/plai..scrbl).'._.'.Testing_.Mutators_with_.G.C2.'))", "../plai/gc2-mutator.html#%28part._.Testing_.Mutators_with_.G.C2%29"],
 ["(part._(.'(lib._plai/scribblings/plai..scrbl).'._.'gc2-collector.'))", "../plai/gc2-collector.html"],
 ["(part._(.'(lib._planet/planet..scrbl).'._.'.Create_an__info_rkt__.File__.Optional_.'))", "../planet/Developing_Packages_for_PLaneT.html#%28part._.Create_an__info_rkt__.File__.Optional_%29"],
 ["(part._(.'(lib._planet/planet..scrbl).'._.'.Resolver_file_locking.'))", "../planet/Utility_Libraries.html#%28part._.Resolver_file_locking%29"],
 ["(part._(.'(lib._planet/planet..scrbl).'._.'.Shorthand_.Syntax.'))", "../planet/Using_PLaneT.html#%28part._.Shorthand_.Syntax%29"],
 ["(part._(.'(lib._planet/planet..scrbl).'._.'fileinject.'))", "../planet/cmdline.html#%28part._fileinject%29"],
 ["(part._(.'(lib._planet/planet..scrbl).'._.'search-order.'))", "../planet/search-order.html"],
 ["(part._(.'(lib._planet/planet..scrbl).'._.'show.'))", "../planet/cmdline.html#%28part._show%29"],
 ["(part._(.'(lib._planet/planet..scrbl).'._.'structure.'))", "../planet/cmdline.html#%28part._structure%29"],
 ["(part._(.'(lib._planet/planet..scrbl).'._.'unlink.'))", "../planet/cmdline.html#%28part._unlink%29"],
 ["(part._(.'(lib._planet/planet..scrbl).'._.'url.'))", "../planet/cmdline.html#%28part._url%29"],
 ["(part._(.'(lib._planet/planet..scrbl).'._.'util..rkt.'))", "../planet/Utility_Libraries.html#%28part._util..rkt%29"],
 ["(part._(.'(lib._planet/planet..scrbl).'._.'version..rkt.'))", "../planet/Utility_Libraries.html#%28part._version..rkt%29"],
 ["(part._(.'(lib._plot/scribblings/plot..scrbl).'._.'.Currency_.Ticks.'))", "../plot/ticks_and_transforms.html#%28part._.Currency_.Ticks%29"],
 ["(part._(.'(lib._plot/scribblings/plot..scrbl).'._.'.Linear_.Ticks.'))", "../plot/ticks_and_transforms.html#%28part._.Linear_.Ticks%29"],
 ["(part._(.'(lib._plot/scribblings/plot..scrbl).'._.'.Non-.G.U.I_.Plotting_.Procedures.'))", "../plot/plotting.html#%28part._.Non-.G.U.I_.Plotting_.Procedures%29"],
 ["(part._(.'(lib._plot/scribblings/plot..scrbl).'._.'.Plot_.Element_.Contracts.'))", "../plot/contracts.html#%28part._.Plot_.Element_.Contracts%29"],
 ["(part._(.'(lib._plot/scribblings/plot..scrbl).'._.'.Tick_.Data_.Types_and_.Contracts.'))", "../plot/ticks_and_transforms.html#%28part._.Tick_.Data_.Types_and_.Contracts%29"],
 ["(part._(.'(lib._plot/scribblings/plot..scrbl).'._.'2.D_.Contour__.Isoline__.Renderers.'))", "../plot/renderer2d.html#%28part._2.D_.Contour__.Isoline__.Renderers%29"],
 ["(part._(.'(lib._plot/scribblings/plot..scrbl).'._.'invertible.'))", "../plot/ticks_and_transforms.html#%28part._invertible%29"],
 ["(part._(.'(lib._plot/scribblings/plot..scrbl).'._.'ticks.'))", "../plot/ticks_and_transforms.html#%28part._ticks%29"],
 ["(part._(.'(lib._r6rs/scribblings/r6rs..scrbl).'._.'.R6.R.S__.Scheme.'))", "../r6rs/index.html"],
 ["(part._(.'(lib._r6rs/scribblings/r6rs..scrbl).'._.'r6rs-mod.'))", "../r6rs/r6rs-mod.html"],
 ["(part._(.'(lib._r6rs/scribblings/r6rs..scrbl).'._.'rnrs/io/simple-6.'))", "../r6rs/R6RS_Libraries.html#%28part._rnrs%2Fio%2Fsimple-6%29"],
 ["(part._(.'(lib._racklog/racklog..scrbl).'._.'.Racket_.Predicates.'))", "../racklog/glossary.html#%28part._.Racket_.Predicates%29"],
 ["(part._(.'(lib._racklog/racklog..scrbl).'._.'.Relations.'))", "../racklog/glossary.html#%28part._.Relations%29"],
 ["(part._(.'(lib._racklog/racklog..scrbl).'._.'solving-goals.'))", "../racklog/predicates.html#%28part._solving-goals%29"],
 ["(part._(.'(lib._racklog/racklog..scrbl).'._.'unification.'))", "../racklog/unification.html"],
 ["(part._(.'(lib._racklog/racklog..scrbl).'._.'var.'))", "../racklog/lv-manip.html#%28part._var%29"],
 ["(part._(.'(lib._rackunit/scribblings/rackunit..scrbl).'._.'.Compound_.Testing_.Forms.'))", "../rackunit/api.html#%28part._.Compound_.Testing_.Forms%29"],
 ["(part._(.'(lib._rackunit/scribblings/rackunit..scrbl).'._.'.Rack.Unit__.Unit_.Testing.'))", "../rackunit/index.html"],
 ["(part._(.'(lib._rackunit/scribblings/rackunit..scrbl).'._.'.Utilities_for_.Defining_.Test_.Suites.'))", "../rackunit/api.html#%28part._.Utilities_for_.Defining_.Test_.Suites%29"],
 ["(part._(.'(lib._rackunit/scribblings/rackunit..scrbl).'._.'quick-start.'))", "../rackunit/quick-start.html"],
 ["(part._(.'(lib._readline/readline..scrbl).'._.'.Direct_.Bindings_for_.Readline_.Hackers.'))", "../readline/index.html#%28part._.Direct_.Bindings_for_.Readline_.Hackers%29"],
 ["(part._(.'(lib._redex/redex..scrbl).'._.'.Defining_a_.Reduction_.Relation.'))", "../redex/tutorial.html#%28part._.Defining_a_.Reduction_.Relation%29"],
 ["(part._(.'(lib._redex/redex..scrbl).'._.'.Developing_a_.Language_2.'))", "../redex/redex2015.html#%28part._.Developing_a_.Language_2%29"],
 ["(part._(.'(lib._redex/redex..scrbl).'._.'.Languages.'))", "../redex/The_Redex_Reference.html#%28part._.Languages%29"],
 ["(part._(.'(lib._redex/redex..scrbl).'._.'.Problem__.G.C.'))", "../redex/Problem__GC.html"],
 ["(part._(.'(lib._redex/redex..scrbl).'._.'.Problem__.Missionaries_and_.Cannibals.'))", "../redex/Problem__Missionaries_and_Cannibals.html"],
 ["(part._(.'(lib._redex/redex..scrbl).'._.'.Redex__.Practical_.Semantics_.Engineering.'))", "../redex/index.html"],
 ["(part._(.'(lib._redex/redex..scrbl).'._.'.Solution__.Finite_.State_.Machines.'))", "../redex/Solution__Finite_State_Machines.html"],
 ["(part._(.'(lib._redex/redex..scrbl).'._.'.Solution__.G.C.'))", "../redex/Solution__GC.html"],
 ["(part._(.'(lib._redex/redex..scrbl).'._.'.Terms.'))", "../redex/The_Redex_Reference.html#%28part._.Terms%29"],
 ["(part._(.'(lib._redex/redex..scrbl).'._.'.Typesetting_the_.Reduction_.Relation.'))", "../redex/tutorial.html#%28part._.Typesetting_the_.Reduction_.Relation%29"],
 ["(part._(.'(lib._redex/redex..scrbl).'._.'.Typing.'))", "../redex/tutorial.html#%28part._.Typing%29"],
 ["(part._(.'(lib._redex/redex..scrbl).'._.'lab-tue-mor.'))", "../redex/redex2015.html#%28part._lab-tue-mor%29"],
 ["(part._(.'(lib._redex/redex..scrbl).'._.'ltm.'))", "../redex/redex2015.html#%28part._ltm%29"],
 ["(part._(.'(lib._redex/redex..scrbl).'._.'sec~3ab~3alet-poly.'))", "../redex/benchmark.html#%28part._sec~3ab~3alet-poly%29"],
 ["(part._(.'(lib._redex/redex..scrbl).'._.'top.'))", "../redex/index.html"],
 ["(part._(.'(lib._redex/redex..scrbl).'._.'tue-mor.'))", "../redex/redex2015.html#%28part._tue-mor%29"],
 ["(part._(.'(lib._scribblings/distributed-places/distributed-places..scrbl).'._.'distributed-places.'))", "../distributed-places/index.html"],
 ["(part._(.'(lib._scribblings/draw/draw..scrbl).'._.'.Alpha_.Channels_and_.Alpha_.Blending.'))", "../draw/overview.html#%28part._.Alpha_.Channels_and_.Alpha_.Blending%29"],
 ["(part._(.'(lib._scribblings/draw/draw..scrbl).'._.'.Drawing_.Contracts.'))", "../draw/Drawing_Contracts.html"],
 ["(part._(.'(lib._scribblings/draw/draw..scrbl).'._.'.Transformations.'))", "../draw/overview.html#%28part._.Transformations%29"],
 ["(part._(.'(lib._scribblings/draw/draw..scrbl).'._.'bitmap-dc_.'))", "../draw/bitmap-dc_.html"],
 ["(part._(.'(lib._scribblings/draw/draw..scrbl).'._.'dc___.'))", "../draw/dc___.html"],
 ["(part._(.'(lib._scribblings/draw/draw..scrbl).'._.'font_.'))", "../draw/font_.html"],
 ["(part._(.'(lib._scribblings/drracket/drracket..scrbl).'._.'.Adding_.Your_.Own_.Teachpacks_to_the_.Teachpack_.Dialog.'))", "../drracket/extending-drracket.html#%28part._.Adding_.Your_.Own_.Teachpacks_to_the_.Teachpack_.Dialog%29"],
 ["(part._(.'(lib._scribblings/drracket/drracket..scrbl).'._.'.Input_and_.Output.'))", "../drracket/interactions-window.html#%28part._.Input_and_.Output%29"],
 ["(part._(.'(lib._scribblings/drracket/drracket..scrbl).'._.'.Profiling.'))", "../drracket/prefs-explanation.html#%28part._.Profiling%29"],
 ["(part._(.'(lib._scribblings/drracket/drracket..scrbl).'._.'interactions-window.'))", "../drracket/interactions-window.html"],
 ["(part._(.'(lib._scribblings/foreign/foreign..scrbl).'._.'.Atomic_.Execution.'))", "../foreign/Atomic_Execution.html"],
 ["(part._(.'(lib._scribblings/foreign/foreign..scrbl).'._.'.By-.Reference_.Arguments.'))", "../foreign/intro.html#%28part._.By-.Reference_.Arguments%29"],
 ["(part._(.'(lib._scribblings/foreign/foreign..scrbl).'._.'.C.O.M_.Objects.'))", "../foreign/com-auto.html#%28part._.C.O.M_.Objects%29"],
 ["(part._(.'(lib._scribblings/foreign/foreign..scrbl).'._.'.Class_.Display_.Names.'))", "../foreign/com-auto.html#%28part._.Class_.Display_.Names%29"],
 ["(part._(.'(lib._scribblings/foreign/foreign..scrbl).'._.'.Enumerations_and_.Masks.'))", "../foreign/Enumerations_and_Masks.html"],
 ["(part._(.'(lib._scribblings/foreign/foreign..scrbl).'._.'.Fixed_.Auto-.Converting_.String_.Types.'))", "../foreign/String_Types.html#%28part._.Fixed_.Auto-.Converting_.String_.Types%29"],
 ["(part._(.'(lib._scribblings/foreign/foreign..scrbl).'._.'.Function-.Type_.Bells_and_.Whistles.'))", "../foreign/intro.html#%28part._.Function-.Type_.Bells_and_.Whistles%29"],
 ["(part._(.'(lib._scribblings/foreign/foreign..scrbl).'._.'.Interface_.Pointers.'))", "../foreign/com-auto.html#%28part._.Interface_.Pointers%29"],
 ["(part._(.'(lib._scribblings/foreign/foreign..scrbl).'._.'.Obtaining_.C.O.M_.Interface_.References.'))", "../foreign/com-intf.html#%28part._.Obtaining_.C.O.M_.Interface_.References%29"],
 ["(part._(.'(lib._scribblings/foreign/foreign..scrbl).'._.'remote.'))", "../foreign/com-auto.html#%28part._remote%29"],
 ["(part._(.'(lib._scribblings/foreign/foreign..scrbl).'._.'winapi.'))", "../foreign/winapi.html"],
 ["(part._(.'(lib._scribblings/framework/framework..scrbl).'._.'.Framework_.Libraries_.Overview.'))", "../framework/Framework_Libraries_Overview.html"],
 ["(part._(.'(lib._scribblings/framework/framework..scrbl).'._.'.Preferences.'))", "../framework/Preferences.html"],
 ["(part._(.'(lib._scribblings/framework/framework..scrbl).'._.'.Test_.Functions.'))", "../framework/Test.html#%28part._.Test_.Functions%29"],
 ["(part._(.'(lib._scribblings/framework/framework..scrbl).'._.'.Version.'))", "../framework/Version.html"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'.Dr.Racket_.Test-.Case_.Boxes.'))", "../gui/WXME_Decoding.html#%28part._.Dr.Racket_.Test-.Case_.Boxes%29"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'.Init_.Libraries.'))", "../gui/Init_Libraries.html"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'.Miscellaneous.'))", "../gui/Windowing_Functions.html#%28part._.Miscellaneous%29"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'.Nested_.Editors.'))", "../gui/WXME_Decoding.html#%28part._.Nested_.Editors%29"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'.System_.Menus.'))", "../gui/Windowing_Functions.html#%28part._.System_.Menus%29"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'choice_.'))", "../gui/choice_.html"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'combo-field_.'))", "../gui/combo-field_.html"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'containeroverview.'))", "../gui/windowing-overview.html#%28part._containeroverview%29"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'editor-admin_.'))", "../gui/editor-admin_.html"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'editor___.'))", "../gui/editor___.html"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'editorcutandpastetime.'))", "../gui/editor-overview.html#%28part._editorcutandpastetime%29"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'editorthreads.'))", "../gui/editor-overview.html#%28part._editorthreads%29"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'grow-box-spacer-pane_.'))", "../gui/grow-box-spacer-pane_.html"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'horizontal-pane_.'))", "../gui/horizontal-pane_.html"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'keymap_.'))", "../gui/keymap_.html"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'labelled-menu-item___.'))", "../gui/labelled-menu-item___.html"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'libs.'))", "../gui/libs.html"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'menu-bar_.'))", "../gui/menu-bar_.html"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'menu-item-container___.'))", "../gui/menu-item-container___.html"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'menu-item___.'))", "../gui/menu-item___.html"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'pasteboard_.'))", "../gui/pasteboard_.html"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'radio-box_.'))", "../gui/radio-box_.html"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'readable-snip___.'))", "../gui/readable-snip___.html"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'slider_.'))", "../gui/slider_.html"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'snipclassmapping.'))", "../gui/WXME_Decoding.html#%28part._snipclassmapping%29"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'tb~3amiaoverview.'))", "../gui/editor-overview.html#%28part._tb~3amiaoverview%29"],
 ["(part._(.'(lib._scribblings/gui/gui..scrbl).'._.'text_.'))", "../gui/text_.html"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'.A_.Dictionary.'))", "../guide/contracts-examples.html#%28part._.A_.Dictionary%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'.Channels.'))", "../guide/concurrency.html#%28part._.Channels%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'.Class_.Contracts.'))", "../guide/classes.html#%28part._.Class_.Contracts%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'.Definitions.'))", "../guide/syntax-overview.html#%28part._.Definitions%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'.Definitions_and_.Interactions.'))", "../guide/intro.html#%28part._.Definitions_and_.Interactions%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'.Effects_.After__begin0.'))", "../guide/begin.html#%28part._.Effects_.After__begin0%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'.Function_.Shorthand.'))", "../guide/define.html#%28part._.Function_.Shorthand%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'.List_.Iteration_from_.Scratch.'))", "../guide/Lists__Iteration__and_Recursion.html#%28part._.List_.Iteration_from_.Scratch%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'.Major_.Modes.'))", "../guide/Emacs.html#%28part._.Major_.Modes%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'.Namespaces_and_.Modules.'))", "../guide/eval.html#%28part._.Namespaces_and_.Modules%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'.P.O.S.I.X_character_classes.'))", "../guide/regexp-chars.html#%28part._.P.O.S.I.X_character_classes%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'.Phases_and_.Modules.'))", "../guide/phases.html#%28part._.Phases_and_.Modules%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'.Simple_.Branching__if.'))", "../guide/conditionals.html#%28part._.Simple_.Branching__if%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'.Vim.'))", "../guide/Vim.html"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'.Whole-module_.Signatures_and_.Units.'))", "../guide/Whole-module_Signatures_and_Units.html"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'.Windows_.Batch_.Files.'))", "../guide/scripts.html#%28part._.Windows_.Batch_.Files%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'apply.'))", "../guide/application.html#%28part._apply%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'bytestrings.'))", "../guide/bytestrings.html"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'case.'))", "../guide/case.html"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'cmdline-tools.'))", "../guide/cmdline-tools.html"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'code-inspectors+protect.'))", "../guide/stx-certs.html#%28part._code-inspectors%2Bprotect%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'contracts-dissecting-contract-errors.'))", "../guide/contract-func.html#%28part._contracts-dissecting-contract-errors%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'contracts-first.'))", "../guide/contracts-first.html"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'contracts-gotcha-nested.'))", "../guide/contracts-gotchas.html#%28part._contracts-gotcha-nested%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'contracts-no-domain.'))", "../guide/contracts-general-functions.html#%28part._contracts-no-domain%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'contracts-single-struct.'))", "../guide/contracts-struct.html#%28part._contracts-single-struct%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'define-syntax-rule.'))", "../guide/pattern-macros.html#%28part._define-syntax-rule%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'distributed-places.'))", "../guide/parallelism.html#%28part._distributed-places%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'effective-places.'))", "../guide/parallelism.html#%28part._effective-places%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'for_and_for_.'))", "../guide/for.html#%28part._for_and_for_%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'for_vector_and_for__vector.'))", "../guide/for.html#%28part._for_vector_and_for__vector%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'inner.'))", "../guide/classes.html#%28part._inner%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'intro.'))", "../guide/intro.html"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'letrec-performance.'))", "../guide/performance.html#%28part._letrec-performance%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'module-basics.'))", "../guide/module-basics.html"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'module-require.'))", "../guide/module-require.html"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'module-syntax.'))", "../guide/Module_Syntax.html#%28part._module-syntax%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'modules-performance.'))", "../guide/performance.html#%28part._modules-performance%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'pattern-macro-example.'))", "../guide/pattern-macros.html#%28part._pattern-macro-example%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'prompt.'))", "../guide/prompt.html"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'rest-args.'))", "../guide/lambda.html#%28part._rest-args%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'scripts.'))", "../guide/scripts.html"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'sequences.'))", "../guide/for.html#%28part._sequences%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'set__.Transformers.'))", "../guide/pattern-macros.html#%28part._set__.Transformers%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'struct-equal.'))", "../guide/define-struct.html#%28part._struct-equal%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'taints+code-inspectors.'))", "../guide/stx-certs.html#%28part._taints%2Bcode-inspectors%29"],
 ["(part._(.'(lib._scribblings/guide/guide..scrbl).'._.'unit_versus_module.'))", "../guide/unit_versus_module.html"],
 ["(part._(.'(lib._scribblings/htdp-langs/htdp-langs..scrbl).'._.'advanced-pre-defined.'))", "../htdp-langs/advanced.html#%28part._advanced-pre-defined%29"],
 ["(part._(.'(lib._scribblings/htdp-langs/htdp-langs..scrbl).'._.'advanced-syntax.'))", "../htdp-langs/advanced.html#%28part._advanced-syntax%29"],
 ["(part._(.'(lib._scribblings/htdp-langs/htdp-langs..scrbl).'._.'advanced._.Pre-.Defined._.Variables.'))", "../htdp-langs/advanced.html#%28part._advanced._.Pre-.Defined._.Variables%29"],
 ["(part._(.'(lib._scribblings/htdp-langs/htdp-langs..scrbl).'._.'beginner-abbr-common-syntax.'))", "../htdp-langs/beginner-abbr.html#%28part._beginner-abbr-common-syntax%29"],
 ["(part._(.'(lib._scribblings/htdp-langs/htdp-langs..scrbl).'._.'beginner-abbr._.Pre-.Defined._.Variables.'))", "../htdp-langs/beginner-abbr.html#%28part._beginner-abbr._.Pre-.Defined._.Variables%29"],
 ["(part._(.'(lib._scribblings/htdp-langs/htdp-langs..scrbl).'._.'beginner-pre-defined.'))", "../htdp-langs/beginner.html#%28part._beginner-pre-defined%29"],
 ["(part._(.'(lib._scribblings/htdp-langs/htdp-langs..scrbl).'._.'htdp-advanced.'._.'.Higher-.Order_.Functions.'))", "../htdp-langs/advanced.html#%28part._htdp-advanced._.Higher-.Order_.Functions%29"],
 ["(part._(.'(lib._scribblings/htdp-langs/htdp-langs..scrbl).'._.'htdp-advanced.'._.'.Reading_and_.Printing.'))", "../htdp-langs/advanced.html#%28part._htdp-advanced._.Reading_and_.Printing%29"],
 ["(part._(.'(lib._scribblings/htdp-langs/htdp-langs..scrbl).'._.'htdp-advanced.'._.'.Strings.'))", "../htdp-langs/advanced.html#%28part._htdp-advanced._.Strings%29"],
 ["(part._(.'(lib._scribblings/htdp-langs/htdp-langs..scrbl).'._.'htdp-beginner-abbr.'._.'.Images.'))", "../htdp-langs/beginner-abbr.html#%28part._htdp-beginner-abbr._.Images%29"],
 ["(part._(.'(lib._scribblings/htdp-langs/htdp-langs..scrbl).'._.'htdp-beginner-abbr.'._.'.Numbers__.Integers__.Rationals__.Reals__.Complex__.Exacts__.Inexacts.'))", "../htdp-langs/beginner-abbr.html#%28part._htdp-beginner-abbr._.Numbers__.Integers__.Rationals__.Reals__.Complex__.Exacts__.Inexacts%29"],
 ["(part._(.'(lib._scribblings/htdp-langs/htdp-langs..scrbl).'._.'htdp-beginner-abbr.'._.'.Strings.'))", "../htdp-langs/beginner-abbr.html#%28part._htdp-beginner-abbr._.Strings%29"],
 ["(part._(.'(lib._scribblings/htdp-langs/htdp-langs..scrbl).'._.'htdp-beginner.'._.'.Characters.'))", "../htdp-langs/beginner.html#%28part._htdp-beginner._.Characters%29"],
 ["(part._(.'(lib._scribblings/htdp-langs/htdp-langs..scrbl).'._.'intermediate-lam.'))", "../htdp-langs/intermediate-lam.html"],
 ["(part._(.'(lib._scribblings/htdp-langs/htdp-langs..scrbl).'._.'intm-w-lambda-syntax.'))", "../htdp-langs/intermediate-lam.html#%28part._intm-w-lambda-syntax%29"],
 ["(part._(.'(lib._scribblings/inside/inside..scrbl).'._.'.Building_.Racket_from_.Source.'))", "../inside/overview.html#%28part._.Building_.Racket_from_.Source%29"],
 ["(part._(.'(lib._scribblings/inside/inside..scrbl).'._.'.Declaring_a_.Module_in_an_.Extension.'))", "../inside/Writing_Racket_Extensions.html#%28part._.Declaring_a_.Module_in_an_.Extension%29"],
 ["(part._(.'(lib._scribblings/inside/inside..scrbl).'._.'.Evaluation_.Functions.'))", "../inside/Evaluation.html#%28part._.Evaluation_.Functions%29"],
 ["(part._(.'(lib._scribblings/inside/inside..scrbl).'._.'.Flags_and_.Hooks.'))", "../inside/embedding.html#%28part._.Flags_and_.Hooks%29"],
 ["(part._(.'(lib._scribblings/inside/inside..scrbl).'._.'exceptions.'))", "../inside/exceptions.html"],
 ["(part._(.'(lib._scribblings/inside/inside..scrbl).'._.'im~3a3m~3atagged.'))", "../inside/im_memoryalloc.html#%28part._im~3a3m~3atagged%29"],
 ["(part._(.'(lib._scribblings/inside/inside..scrbl).'._.'im~3aencodings.'))", "../inside/im_encodings.html"],
 ["(part._(.'(lib._scribblings/inside/inside..scrbl).'._.'im~3aintsize.'))", "../inside/overview.html#%28part._im~3aintsize%29"],
 ["(part._(.'(lib._scribblings/inside/inside..scrbl).'._.'im~3amemoryalloc.'))", "../inside/im_memoryalloc.html"],
 ["(part._(.'(lib._scribblings/inside/inside..scrbl).'._.'im~3astdtypes.'))", "../inside/im_values_types.html#%28part._im~3astdtypes%29"],
 ["(part._(.'(lib._scribblings/inside/inside..scrbl).'._.'places.'))", "../inside/overview.html#%28part._places%29"],
 ["(part._(.'(lib._scribblings/inside/inside..scrbl).'._.'security.'))", "../inside/security.html"],
 ["(part._(.'(lib._scribblings/more/more..scrbl).'._.'.Servlets_and_.Sessions.'))", "../more/index.html#%28part._.Servlets_and_.Sessions%29"],
 ["(part._(.'(lib._scribblings/more/more..scrbl).'._.'.Terminating_.Connections.'))", "../more/index.html#%28part._.Terminating_.Connections%29"],
 ["(part._(.'(lib._scribblings/more/more..scrbl).'._.'.Where_to_.Go_.From_.Here.'))", "../more/index.html#%28part._.Where_to_.Go_.From_.Here%29"],
 ["(part._(.'(lib._scribblings/more/more..scrbl).'._.'go.'))", "../more/index.html#%28part._go%29"],
 ["(part._(.'(lib._scribblings/pict-snip/pict-snip..scrbl).'._.'.Pict_.Snip__.Build_.Snips_from_.Picts.'))", "../pict-snip/index.html"],
 ["(part._(.'(lib._scribblings/quick/quick..scrbl).'._.'.Objects.'))", "../quick/index.html#%28part._.Objects%29"],
 ["(part._(.'(lib._scribblings/raco/raco..scrbl).'._.'.A.P.I_for_.Bundling_.Distributions.'))", "../raco/exe-dist.html#%28part._.A.P.I_for_.Bundling_.Distributions%29"],
 ["(part._(.'(lib._scribblings/raco/raco..scrbl).'._.'.A.P.I_for_.Decompiling.'))", "../raco/decompile.html#%28part._.A.P.I_for_.Decompiling%29"],
 ["(part._(.'(lib._scribblings/raco/raco..scrbl).'._.'.Non-.G.U.I_.Installer.'))", "../raco/_plt-archives.html#%28part._.Non-.G.U.I_.Installer%29"],
 ["(part._(.'(lib._scribblings/raco/raco..scrbl).'._.'decompile.'))", "../raco/decompile.html"],
 ["(part._(.'(lib._scribblings/raco/raco..scrbl).'._.'exe.'))", "../raco/exe.html"],
 ["(part._(.'(lib._scribblings/raco/raco..scrbl).'._.'expand.'))", "../raco/expand.html"],
 ["(part._(.'(lib._scribblings/raco/raco..scrbl).'._.'format-of-..plt-archives.'))", "../raco/plt.html#%28part._format-of-..plt-archives%29"],
 ["(part._(.'(lib._scribblings/raco/raco..scrbl).'._.'link.'))", "../raco/link.html"],
 ["(part._(.'(lib._scribblings/raco/raco..scrbl).'._.'raco__.Racket_.Command-.Line_.Tools.'))", "../raco/index.html"],
 ["(part._(.'(lib._scribblings/raco/raco..scrbl).'._.'raco_setup_.Unit.'))", "../raco/setup-plt-plt.html#%28part._raco_setup_.Unit%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.'))", "../reference/Kernel_Forms_and_Functions.html#%28part._%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Arithmetic.'))", "../reference/generic-numbers.html#%28part._.Arithmetic%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Bitwise_.Operations.'))", "../reference/generic-numbers.html#%28part._.Bitwise_.Operations%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Byte_and_.String_.Output.'))", "../reference/Byte_and_String_Output.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Bytes_to_from_.Characters__.Decoding_and_.Encoding.'))", "../reference/bytestrings.html#%28part._.Bytes_to_from_.Characters__.Decoding_and_.Encoding%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Characters_and_.Scalar_.Values.'))", "../reference/characters.html#%28part._.Characters_and_.Scalar_.Values%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Creating_and_.Touching_.Futures.'))", "../reference/futures.html#%28part._.Creating_and_.Touching_.Futures%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Creating_and_.Using_.Asynchronous_.Channels.'))", "../reference/async-channel.html#%28part._.Creating_and_.Using_.Asynchronous_.Channels%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Custom_.Hash_.Sets.'))", "../reference/sets.html#%28part._.Custom_.Hash_.Sets%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Custom_.Hash_.Tables.'))", "../reference/dicts.html#%28part._.Custom_.Hash_.Tables%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Extra_.Constants_and_.Functions.'))", "../reference/generic-numbers.html#%28part._.Extra_.Constants_and_.Functions%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Generating_.A_.Unit_from_.Context.'))", "../reference/Generating_A_Unit_from_Context.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Generic_.Dictionary_.Interface.'))", "../reference/dicts.html#%28part._.Generic_.Dictionary_.Interface%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Generic_.Set_.Interface.'))", "../reference/sets.html#%28part._.Generic_.Set_.Interface%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Generics.'))", "../reference/ivaraccess.html#%28part._.Generics%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Interacting_with_.Evaluators.'))", "../reference/Sandboxed_Evaluation.html#%28part._.Interacting_with_.Evaluators%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Iteration_and_.Comprehension_.Forms.'))", "../reference/for.html#%28part._.Iteration_and_.Comprehension_.Forms%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Keywords_and_.Arity.'))", "../reference/procedures.html#%28part._.Keywords_and_.Arity%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Library_.Extensions.'))", "../reference/match.html#%28part._.Library_.Extensions%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Line-.Output_.Hook.'))", "../reference/pretty-print.html#%28part._.Line-.Output_.Hook%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.List_.Iteration.'))", "../reference/pairs.html#%28part._.List_.Iteration%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Locale-.Specific_.String_.Operations.'))", "../reference/strings.html#%28part._.Locale-.Specific_.String_.Operations%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Miscellaneous.'))", "../reference/Sandboxed_Evaluation.html#%28part._.Miscellaneous%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Namespaces.'))", "../reference/Namespaces.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Number--.String_.Conversions.'))", "../reference/generic-numbers.html#%28part._.Number--.String_.Conversions%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Obligation_.Information_in_.Check_.Syntax.'))", "../reference/Building_New_Contract_Combinators.html#%28part._.Obligation_.Information_in_.Check_.Syntax%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Pattern_variables.'))", "../reference/syntax-util.html#%28part._.Pattern_variables%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Random_.Numbers.'))", "../reference/generic-numbers.html#%28part._.Random_.Numbers%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Security_.Considerations.'))", "../reference/Sandboxed_Evaluation.html#%28part._.Security_.Considerations%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'.Trigonometric_.Functions.'))", "../reference/generic-numbers.html#%28part._.Trigonometric_.Functions%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'application.'))", "../reference/application.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'attaching-contracts-to-values.'))", "../reference/attaching-contracts-to-values.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'case.'))", "../reference/case.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'characters.'))", "../reference/characters.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'collects-api.'))", "../reference/collects.html#%28part._collects-api%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'collects-search.'))", "../reference/collects.html#%28part._collects-search%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'contmarks.'))", "../reference/contmarks.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'creatingmorestructs.'))", "../reference/creatingmorestructs.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'customport.'))", "../reference/customport.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'date-string.'))", "../reference/time.html#%28part._date-string%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'debugging.'))", "../reference/debugging.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'encodings.'))", "../reference/encodings.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'enter.'))", "../reference/interactive.html#%28part._enter%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'eval-model.'))", "../reference/eval-model.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'exns.'))", "../reference/exns.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'expand-context-model.'))", "../reference/syntax-model.html#%28part._expand-context-model%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'extflutils.'))", "../reference/extflonums.html#%28part._extflutils%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'flonums.'))", "../reference/flonums.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'fully-expanded.'))", "../reference/syntax-model.html#%28part._fully-expanded%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'function-contracts.'))", "../reference/function-contracts.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'gc-model.'))", "../reference/eval-model.html#%28part._gc-model%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'generic-numbers.'))", "../reference/generic-numbers.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'include.'))", "../reference/include.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'infernames.'))", "../reference/syntax-model.html#%28part._infernames%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'ivaraccess.'))", "../reference/ivaraccess.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'keywords.'))", "../reference/keywords.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'linecol.'))", "../reference/linecol.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'links-file.'))", "../reference/collects.html#%28part._links-file%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'methodcalls.'))", "../reference/ivaraccess.html#%28part._methodcalls%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'mixins.'))", "../reference/mixins.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'mod-parse.'))", "../reference/syntax-model.html#%28part._mod-parse%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'module.'))", "../reference/module.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'mz-cmdline.'))", "../reference/running-sa.html#%28part._mz-cmdline%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'objectutils.'))", "../reference/objectutils.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'parse-extflonum.'))", "../reference/reader.html#%28part._parse-extflonum%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'parse-hashtable.'))", "../reference/reader.html#%28part._parse-hashtable%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'parse-symbol.'))", "../reference/reader.html#%28part._parse-symbol%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'pathutils.'))", "../reference/pathutils.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'performance-hint.'))", "../reference/performance-hint.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'plumbers.'))", "../reference/plumbers.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'print-hashtable.'))", "../reference/printing.html#%28part._print-hashtable%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'print-vectors.'))", "../reference/printing.html#%28part._print-vectors%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'quote.'))", "../reference/quote.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'running-sa.'))", "../reference/running-sa.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'special-comments.'))", "../reference/special-comments.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'struct-generics.'))", "../reference/struct-generics.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'stxobj-model.'))", "../reference/syntax-model.html#%28part._stxobj-model%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'trait.'))", "../reference/trait.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'unsafe.'))", "../reference/unsafe.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'values-model.'))", "../reference/eval-model.html#%28part._values-model%29"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'values.'))", "../reference/values.html"],
 ["(part._(.'(lib._scribblings/reference/reference..scrbl).'._.'~23~25top-interaction.'))", "../reference/__top-interaction.html"],
 ["(part._(.'(lib._scribblings/scheme/scheme..scrbl).'._.'mred.'))", "../scheme/mred.html"],
 ["(part._(.'(lib._scribblings/scheme/scheme..scrbl).'._.'scheme_async-channel.'))", "../scheme/scheme_async-channel.html"],
 ["(part._(.'(lib._scribblings/scheme/scheme..scrbl).'._.'scheme_bool.'))", "../scheme/scheme_bool.html"],
 ["(part._(.'(lib._scribblings/scheme/scheme..scrbl).'._.'scheme_cmdline.'))", "../scheme/scheme_cmdline.html"],
 ["(part._(.'(lib._scribblings/scheme/scheme..scrbl).'._.'scheme_foreign.'))", "../scheme/scheme_foreign.html"],
 ["(part._(.'(lib._scribblings/scheme/scheme..scrbl).'._.'scheme_load.'))", "../scheme/scheme_load.html"],
 ["(part._(.'(lib._scribblings/scheme/scheme..scrbl).'._.'scheme_struct-info.'))", "../scheme/scheme_struct-info.html"],
 ["(part._(.'(lib._scribblings/scheme/scheme..scrbl).'._.'scheme_surrogate.'))", "../scheme/scheme_surrogate.html"],
 ["(part._(.'(lib._scribblings/scribble/demo-m1..scrbl).'._.'.Block_.Styles.'))", "../demo-m1/Block_Styles.html"],
 ["(part._(.'(lib._scribblings/scribble/demo-m1..scrbl).'._.'.Enumerations.'))", "../demo-m1/Enumerations.html"],
 ["(part._(.'(lib._scribblings/scribble/demo-m1..scrbl).'._.'.Paragraph_.Spacing.'))", "../demo-m1/Paragraph_Spacing.html"],
 ["(part._(.'(lib._scribblings/scribble/demo-m2..scrbl).'._.'.Element_.Styles.'))", "../demo-m2/Element_Styles.html"],
 ["(part._(.'(lib._scribblings/scribble/demo-m2..scrbl).'._.'.Second_.Subsection_in__.H4_.'))", "../demo-m2/h3.html#%28part._.Second_.Subsection_in__.H4_%29"],
 ["(part._(.'(lib._scribblings/scribble/demo-m2..scrbl).'._.'all-non-sec.'))", "../demo-m2/all-non-sec.html"],
 ["(part._(.'(lib._scribblings/scribble/demo-m2..scrbl).'._.'h3.'))", "../demo-m2/h3.html"],
 ["(part._(.'(lib._scribblings/scribble/demo-manual-m2..scrbl).'._.'bitmap-dc_.'))", "../demo-manual-m2/bitmap-dc_.html"],
 ["(part._(.'(lib._scribblings/scribble/demo-manual-s2..scrbl).'._.'.Code_.Styles.'))", "../demo-manual-s2/index.html#%28part._.Code_.Styles%29"],
 ["(part._(.'(lib._scribblings/scribble/demo-manual-s2..scrbl).'._.'.Miscellaneous.'))", "../demo-manual-s2/index.html#%28part._.Miscellaneous%29"],
 ["(part._(.'(lib._scribblings/scribble/demo-s1..scrbl).'._.'.Paragraph_.Spacing.'))", "../demo-s1/index.html#%28part._.Paragraph_.Spacing%29"],
 ["(part._(.'(lib._scribblings/scribble/demo-s1..scrbl).'._.'.Subsection_in__.H4_.'))", "../demo-s1/index.html#%28part._.Subsection_in__.H4_%29"],
 ["(part._(.'(lib._scribblings/scribble/demo-s1..scrbl).'._.'deepest.'))", "../demo-s1/index.html#%28part._deepest%29"],
 ["(part._(.'(lib._scribblings/scribble/demo-s1..scrbl).'._.'no-toc.'))", "../demo-s1/index.html#%28part._no-toc%29"],
 ["(part._(.'(lib._scribblings/scribble/demo-s2..scrbl).'._.'h3.'))", "../demo-s2/index.html#%28part._h3%29"],
 ["(part._(.'(lib._scribblings/scribble/scribble-pp..scrbl).'._.'doc-index.'))", "../scribble-pp/doc-index.html"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'.Bibliography.'))", "../scribble/Bibliography.html"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'.Blocks.'))", "../scribble/base.html#%28part._.Blocks%29"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'.Defining_.Racket_.Bindings.'))", "../scribble/how-to-doc.html#%28part._.Defining_.Racket_.Bindings%29"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'.Layer_.Roadmap.'))", "../scribble/layers.html#%28part._.Layer_.Roadmap%29"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'.P.D.F_.Renderer.'))", "../scribble/renderer.html#%28part._.P.D.F_.Renderer%29"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'.Selecting_an_.Image_.Format.'))", "../scribble/running.html#%28part._.Selecting_an_.Image_.Format%29"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'.Showing_.Racket_.Examples.'))", "../scribble/how-to-doc.html#%28part._.Showing_.Racket_.Examples%29"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'base-indexing.'))", "../scribble/base.html#%28part._base-indexing%29"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'basic.'))", "../scribble/Compatibility_Libraries.html#%28part._basic%29"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'bnf.'))", "../scribble/bnf.html"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'config-style.'))", "../scribble/config-style.html"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'config.'))", "../scribble/config.html"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'doc-forms.'))", "../scribble/doc-forms.html"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'doc-modules.'))", "../scribble/doc-modules.html"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'doc-signatures.'))", "../scribble/doc-signatures.html"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'images.'))", "../scribble/base.html#%28part._images%29"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'lp.'))", "../scribble/lp.html"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'manual-css.'))", "../scribble/manual-css.html"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'racket-code.'))", "../scribble/scribble_manual_code.html#%28part._racket-code%29"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'reader-internals.'))", "../scribble/reader-internals.html"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'setting-up.'))", "../scribble/how-to-doc.html#%28part._setting-up%29"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'srcdoc.'))", "../scribble/srcdoc.html"],
 ["(part._(.'(lib._scribblings/scribble/scribble..scrbl).'._.'tag.'))", "../scribble/tag.html"],
 ["(part._(.'(lib._scribblings/slideshow/slideshow..scrbl).'._.'.Constants_and_.Layout_.Variables.'))", "../slideshow/Constants_and_Layout_Variables.html"],
 ["(part._(.'(lib._scribblings/slideshow/slideshow..scrbl).'._.'.Primary_.Slide_.Functions.'))", "../slideshow/Primary_Slide_Functions.html"],
 ["(part._(.'(lib._scribblings/slideshow/slideshow..scrbl).'._.'.Typesetting_.Racket_.Code_in_.Slideshow.'))", "../slideshow/Typesetting_Racket_Code_in_Slideshow.html"],
 ["(part._(.'(lib._scribblings/style/style..scrbl).'._.'.Indexing.'))", "../style/reference-style.html#%28part._.Indexing%29"],
 ["(part._(.'(lib._scribblings/style/style..scrbl).'._.'.Macros__.Space_and_.Performance.'))", "../style/Language_and_Performance.html#%28part._.Macros__.Space_and_.Performance%29"],
 ["(part._(.'(lib._scribblings/style/style..scrbl).'._.'.Organization_.Matters.'))", "../style/Units_of_Code.html#%28part._.Organization_.Matters%29"],
 ["(part._(.'(lib._scribblings/style/style..scrbl).'._.'.Parameters.'))", "../style/Choosing_the_Right_Construct.html#%28part._.Parameters%29"],
 ["(part._(.'(lib._scribblings/style/style..scrbl).'._.'.Textual_.Matters.'))", "../style/Textual_Matters.html"],
 ["(part._(.'(lib._scribblings/style/style..scrbl).'._.'.Unsafe__.Beware.'))", "../style/Language_and_Performance.html#%28part._.Unsafe__.Beware%29"],
 ["(part._(.'(lib._scribblings/style/style..scrbl).'._.'testing.'))", "../style/testing.html"],
 ["(part._(.'(lib._scribblings/tools/tools..scrbl).'._.'.Color_.Schemes.'))", "../tools/Editor_Modes.html#%28part._.Color_.Schemes%29"],
 ["(part._(.'(lib._scribblings/tools/tools..scrbl).'._.'.General-purpose_.Modes.'))", "../tools/Editor_Modes.html#%28part._.General-purpose_.Modes%29"],
 ["(part._(.'(lib._scribblings/tools/tools..scrbl).'._.'.Keystrokes.'))", "../tools/lang-languages-customization.html#%28part._.Keystrokes%29"],
 ["(part._(.'(lib._scribblings/tools/tools..scrbl).'._.'drracket~3aeval.'))", "../tools/drracket_eval.html"],
 ["(part._(.'(lib._scribblings/tools/tools..scrbl).'._.'drracket~3alanguage.'))", "../tools/drracket_language.html"],
 ["(part._(.'(lib._scriblib/scribblings/scriblib..scrbl).'._.'autobib.'))", "../scriblib/autobib.html"],
 ["(part._(.'(lib._setup/plt-installer..scrbl).'._.'.G.U.I_.Unpacking_.Signature.'))", "../plt-installer/index.html#%28part._.G.U.I_.Unpacking_.Signature%29"],
 ["(part._(.'(lib._srfi/scribblings/srfi..scrbl).'._.'.S.R.F.Is__.Libraries.'))", "../srfi/index.html"],
 ["(part._(.'(lib._srfi/scribblings/srfi..scrbl).'._.'srfi-16.'))", "../srfi/srfi-16.html"],
 ["(part._(.'(lib._srfi/scribblings/srfi..scrbl).'._.'srfi-23.'))", "../srfi/srfi-23.html"],
 ["(part._(.'(lib._srfi/scribblings/srfi..scrbl).'._.'srfi-27.'))", "../srfi/srfi-27.html"],
 ["(part._(.'(lib._srfi/scribblings/srfi..scrbl).'._.'srfi-34.'))", "../srfi/srfi-34.html"],
 ["(part._(.'(lib._srfi/scribblings/srfi..scrbl).'._.'srfi-45.'))", "../srfi/srfi-45.html"],
 ["(part._(.'(lib._srfi/scribblings/srfi..scrbl).'._.'srfi-5.'))", "../srfi/srfi-5.html"],
 ["(part._(.'(lib._srfi/scribblings/srfi..scrbl).'._.'srfi-63.'))", "../srfi/srfi-63.html"],
 ["(part._(.'(lib._srfi/scribblings/srfi..scrbl).'._.'srfi-74.'))", "../srfi/srfi-74.html"],
 ["(part._(.'(lib._srfi/scribblings/srfi..scrbl).'._.'srfi-9.'))", "../srfi/srfi-9.html"],
 ["(part._(.'(lib._stepper/scribblings/stepper..scrbl).'._.'.What_is_the_.Stepper_.'))", "../stepper/index.html#%28part._.What_is_the_.Stepper_%29"],
 ["(part._(.'(lib._string-constants/string-constants..scrbl).'._.'.String_.Constants__.G.U.I_.Internationalization.'))", "../string-constants/index.html"],
 ["(part._(.'(lib._string-constants/string-constants..scrbl).'._.'top.'))", "../string-constants/index.html"],
 ["(part._(.'(lib._swindle/swindle..scrbl).'._.'.Libraries.'))", "../swindle/index.html#%28part._.Libraries%29"],
 ["(part._(.'(lib._syntax-color/syntax-color..scrbl).'._.'.Module_.Lexer.'))", "../syntax-color/index.html#%28part._.Module_.Lexer%29"],
 ["(part._(.'(lib._syntax-color/syntax-color..scrbl).'._.'.Syntax_.Color__.Utilities.'))", "../syntax-color/index.html"],
 ["(part._(.'(lib._syntax/scribblings/syntax..scrbl).'._.'.Datum_.Pattern_.Matching.'))", "../syntax/Datum_Pattern_Matching.html"],
 ["(part._(.'(lib._syntax/scribblings/syntax..scrbl).'._.'.Experimental.'))", "../syntax/Experimental.html"],
 ["(part._(.'(lib._syntax/scribblings/syntax..scrbl).'._.'.Head_.Patterns.'))", "../syntax/stxparse-patterns.html#%28part._.Head_.Patterns%29"],
 ["(part._(.'(lib._syntax/scribblings/syntax..scrbl).'._.'.Library_.Syntax_.Classes_and_.Literal_.Sets.'))", "../syntax/Library_Syntax_Classes_and_Literal_Sets.html"],
 ["(part._(.'(lib._syntax/scribblings/syntax..scrbl).'._.'module-helpers.'))", "../syntax/module-helpers.html"],
 ["(part._(.'(lib._syntax/scribblings/syntax..scrbl).'._.'module-reader.'))", "../syntax/reader-helpers.html#%28part._module-reader%29"],
 ["(part._(.'(lib._syntax/scribblings/syntax..scrbl).'._.'stxkeyword.'))", "../syntax/syntax-helpers.html#%28part._stxkeyword%29"],
 ["(part._(.'(lib._syntax/scribblings/syntax..scrbl).'._.'stxparse.'))", "../syntax/stxparse.html"],
 ["(part._(.'(lib._syntax/scribblings/syntax..scrbl).'._.'template.'))", "../syntax/transformer-helpers.html#%28part._template%29"],
 ["(part._(.'(lib._syntax/scribblings/syntax..scrbl).'._.'varied-meanings.'))", "../syntax/varied-meanings.html"],
 ["(part._(.'(lib._teachpack/teachpack..scrbl).'._.'.Understanding_a_.Door.'))", "../teachpack/world.html#%28part._.Understanding_a_.Door%29"],
 ["(part._(.'(lib._teachpack/teachpack..scrbl).'._.'2htdp.'._.'.Exploring_a_.Universe.'))", "../teachpack/2htdpuniverse.html#%28part._.Exploring_a_.Universe%29"],
 ["(part._(.'(lib._teachpack/teachpack..scrbl).'._.'2htdp.'._.'.Image_.Interoperability.'))", "../teachpack/2htdpimage-guide.html#%28part._.Image_.Interoperability%29"],
 ["(part._(.'(lib._teachpack/teachpack..scrbl).'._.'2htdp.'._.'.Image_.Predicates.'))", "../teachpack/2htdpimage.html#%28part._.Image_.Predicates%29"],
 ["(part._(.'(lib._teachpack/teachpack..scrbl).'._.'2htdp.'._.'.Porting_.World_.Programs.'))", "../teachpack/2htdphtdp-port.html#%28part._.Porting_.World_.Programs%29"],
 ["(part._(.'(lib._teachpack/teachpack..scrbl).'._.'2htdp.'._.'.Rotating_and_.Overlaying__.A_.Rotary_.Phone_.Dial.'))", "../teachpack/2htdpimage-guide.html#%28part._.Rotating_and_.Overlaying__.A_.Rotary_.Phone_.Dial%29"],
 ["(part._(.'(lib._teachpack/teachpack..scrbl).'._.'2htdp.'._.'.The_.World_is_.Not_.Enough.'))", "../teachpack/2htdphtdp-port.html#%28part._.The_.World_is_.Not_.Enough%29"],
 ["(part._(.'(lib._teachpack/teachpack..scrbl).'._.'2htdp.'._.'.Two_.Ball_.Tossing_.Worlds.'))", "../teachpack/2htdpuniverse.html#%28part._.Two_.Ball_.Tossing_.Worlds%29"],
 ["(part._(.'(lib._teachpack/teachpack..scrbl).'._.'2htdp.'._.'htdp-port.'))", "../teachpack/2htdphtdp-port.html"],
 ["(part._(.'(lib._teachpack/teachpack..scrbl).'._.'2htdp.'._.'image-guide.'))", "../teachpack/2htdpimage-guide.html"],
 ["(part._(.'(lib._teachpack/teachpack..scrbl).'._.'2htdp.'._.'pc~3a.Shadows.'))", "../teachpack/2htdpPlanet_Cute_Images.html#%28part._pc~3a.Shadows%29"],
 ["(part._(.'(lib._teachpack/teachpack..scrbl).'._.'2htdp.'._.'x.'._.'matching.'))", "../teachpack/2htdpabstraction.html#%28part._x._matching%29"],
 ["(part._(.'(lib._teachpack/teachpack..scrbl).'._.'arrow.'))", "../teachpack/arrow.html"],
 ["(part._(.'(lib._teachpack/teachpack..scrbl).'._.'convert.'))", "../teachpack/convert.html"],
 ["(part._(.'(lib._teachpack/teachpack..scrbl).'._.'gui.'))", "../teachpack/gui.html"],
 ["(part._(.'(lib._teachpack/teachpack..scrbl).'._.'image.'))", "../teachpack/image.html"],
 ["(part._(.'(lib._teachpack/teachpack..scrbl).'._.'master-play.'))", "../teachpack/master-play.html"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-guide..scrbl).'._.'.Annotating_.Expressions.'))", "../ts-guide/more.html#%28part._.Annotating_.Expressions%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-guide..scrbl).'._.'.Annotating_.Functions.'))", "../ts-guide/more.html#%28part._.Annotating_.Functions%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-guide..scrbl).'._.'.Polymorphism.'))", "../ts-guide/types.html#%28part._.Polymorphism%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-guide..scrbl).'._.'.Protecting_.Typed-.Untyped_.Interaction.'))", "../ts-guide/typed-untyped-interaction.html#%28part._.Protecting_.Typed-.Untyped_.Interaction%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-guide..scrbl).'._.'.Type_inference_for_polymorphic_functions.'))", "../ts-guide/caveats.html#%28part._.Type_inference_for_polymorphic_functions%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-guide..scrbl).'._.'.Unsupported_features.'))", "../ts-guide/caveats.html#%28part._.Unsupported_features%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-guide..scrbl).'._.'contract-costs.'))", "../ts-guide/optimization.html#%28part._contract-costs%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-guide..scrbl).'._.'more.'))", "../ts-guide/more.html"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-guide..scrbl).'._.'top.'))", "../ts-guide/index.html"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-guide..scrbl).'._.'types.'))", "../ts-guide/types.html"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Contracts_and_.Unit_.Static_.Information.'))", "../ts-reference/Typed_Units.html#%28part._.Contracts_and_.Unit_.Static_.Information%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Definitions.'))", "../ts-reference/special-forms.html#%28part._.Definitions%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Experimental_.Features.'))", "../ts-reference/Experimental_Features.html"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Exploring_.Types.'))", "../ts-reference/Exploring_Types.html"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Libraries_.Provided_.With_.Typed_.Racket.'))", "../ts-reference/Libraries_Provided_With_Typed_Racket.html"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Signature_.Forms.'))", "../ts-reference/Typed_Units.html#%28part._.Signature_.Forms%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Signatures_and_.Internal_.Definition_.Contexts.'))", "../ts-reference/Typed_Units.html#%28part._.Signatures_and_.Internal_.Definition_.Contexts%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Syntax_.Objects.'))", "../ts-reference/type-ref.html#%28part._.Syntax_.Objects%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Tagged_.Signatures.'))", "../ts-reference/Typed_Units.html#%28part._.Tagged_.Signatures%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Typed_.Racket_.Syntax_.Without_.Type_.Checking.'))", "../ts-reference/Typed_Racket_Syntax_Without_Type_Checking.html"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Typed_.Regions.'))", "../ts-reference/Typed_Regions.html"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Typed_for_typed_framework.'))", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28part._.Typed_for_typed_framework%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Typed_for_typed_images_compile-time.'))", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28part._.Typed_for_typed_images_compile-time%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Typed_for_typed_net_cookie.'))", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28part._.Typed_for_typed_net_cookie%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Typed_for_typed_net_mime.'))", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28part._.Typed_for_typed_net_mime%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Typed_for_typed_net_pop3.'))", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28part._.Typed_for_typed_net_pop3%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Typed_for_typed_net_smtp.'))", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28part._.Typed_for_typed_net_smtp%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Typed_for_typed_net_url-connect.'))", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28part._.Typed_for_typed_net_url-connect%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Typed_for_typed_openssl_sha1.'))", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28part._.Typed_for_typed_openssl_sha1%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Typed_for_typed_racket_gui.'))", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28part._.Typed_for_typed_racket_gui%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Typed_for_typed_racket_random.'))", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28part._.Typed_for_typed_racket_random%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Typed_for_typed_racket_system.'))", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28part._.Typed_for_typed_racket_system%29"],
 ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Typed_for_typed_rackunit_text-ui.'))", "../ts-reference/Libraries_Provided_With_Typed_Racket.html#%28part._.Typed_for_typed_rackunit_text-ui%29"],
 ["(part._(.'(lib._version/version..scrbl).'._.'top.'))", "../version/index.html"],
 ["(part._(.'(lib._web-server/scribblings/tutorial/continue..scrbl).'._.'.Abstracting_the_.Model.'))", "../continue/index.html#%28part._.Abstracting_the_.Model%29"],
 ["(part._(.'(lib._web-server/scribblings/tutorial/continue..scrbl).'._.'.Adding_a_.Back_.Button.'))", "../continue/index.html#%28part._.Adding_a_.Back_.Button%29"],
 ["(part._(.'(lib._web-server/scribblings/tutorial/continue..scrbl).'._.'.Continue__.Web_.Applications_in_.Racket.'))", "../continue/index.html"],
 ["(part._(.'(lib._web-server/scribblings/tutorial/continue..scrbl).'._.'.Extending_the_.Model.'))", "../continue/index.html#%28part._.Extending_the_.Model%29"],
 ["(part._(.'(lib._web-server/scribblings/tutorial/continue..scrbl).'._.'.Moving_.Forward.'))", "../continue/index.html#%28part._.Moving_.Forward%29"],
 ["(part._(.'(lib._web-server/scribblings/tutorial/continue..scrbl).'._.'.Using_.H.T.T.P.S.'))", "../continue/index.html#%28part._.Using_.H.T.T.P.S%29"],
 ["(part._(.'(lib._web-server/scribblings/web-server-internal..scrbl).'._.'.Dispatching_.Server_.Signatures.'))", "../web-server-internal/dispatch-server-unit.html#%28part._.Dispatching_.Server_.Signatures%29"],
 ["(part._(.'(lib._web-server/scribblings/web-server-internal..scrbl).'._.'connection-manager.'))", "../web-server-internal/connection-manager.html"],
 ["(part._(.'(lib._web-server/scribblings/web-server-internal..scrbl).'._.'dispatch-files.'))", "../web-server-internal/dispatch-files.html"],
 ["(part._(.'(lib._web-server/scribblings/web-server-internal..scrbl).'._.'mime-types.'))", "../web-server-internal/mime-types.html"],
 ["(part._(.'(lib._web-server/scribblings/web-server-internal..scrbl).'._.'web-config.'._.'.Unit.'))", "../web-server-internal/Web_Servers.html#%28part._web-config._.Unit%29"],
 ["(part._(.'(lib._web-server/scribblings/web-server-internal..scrbl).'._.'web-server-ref-internal.'))", "../web-server-internal/index.html"],
 ["(part._(.'(lib._web-server/scribblings/web-server..scrbl).'._.'.A.P.I_.Reference.'))", "../web-server/dispatch.html#%28part._.A.P.I_.Reference%29"],
 ["(part._(.'(lib._web-server/scribblings/web-server..scrbl).'._.'.Basic_.Combinators.'))", "../web-server/stateless.html#%28part._.Basic_.Combinators%29"],
 ["(part._(.'(lib._web-server/scribblings/web-server..scrbl).'._.'.Basic_.Formlet_.Usage.'))", "../web-server/formlets.html#%28part._.Basic_.Formlet_.Usage%29"],
 ["(part._(.'(lib._web-server/scribblings/web-server..scrbl).'._.'.Built-in_.U.R.L_patterns.'))", "../web-server/dispatch.html#%28part._.Built-in_.U.R.L_patterns%29"],
 ["(part._(.'(lib._web-server/scribblings/web-server..scrbl).'._.'.Hash-addressed_.Storage.'))", "../web-server/stateless.html#%28part._.Hash-addressed_.Storage%29"],
 ["(part._(.'(lib._web-server/scribblings/web-server..scrbl).'._.'.Imperative_.Dispatch_.Containers.'))", "../web-server/dispatch.html#%28part._.Imperative_.Dispatch_.Containers%29"],
 ["(part._(.'(lib._web-server/scribblings/web-server..scrbl).'._.'.Static.'))", "../web-server/templates.html#%28part._.Static%29"],
 ["(part._(.'(lib._web-server/scribblings/web-server..scrbl).'._.'command-line-tools.'))", "../web-server/run.html#%28part._command-line-tools%29"],
 ["(part._(.'(lib._web-server/scribblings/web-server..scrbl).'._.'cookie.'))", "../web-server/http.html#%28part._cookie%29"],
 ["(part._(.'(lib._web-server/scribblings/web-server..scrbl).'._.'http.'))", "../web-server/http.html"],
 ["(part._(.'(lib._web-server/scribblings/web-server..scrbl).'._.'refresh-servlets.'))", "../web-server/faq.html#%28part._refresh-servlets%29"],
 ["(part._(.'(lib._web-server/scribblings/web-server..scrbl).'._.'response-structs.'))", "../web-server/http.html#%28part._response-structs%29"],
 ["(part._(.'(lib._web-server/scribblings/web-server..scrbl).'._.'servlet-example.'))", "../web-server/servlet.html#%28part._servlet-example%29"],
 ["(part._(.'(lib._web-server/scribblings/web-server..scrbl).'._.'stateless.'))", "../web-server/stateless.html"],
 ["(part._(.'(lib._web-server/scribblings/web-server..scrbl).'._.'web-cells.'))", "../web-server/servlet.html#%28part._web-cells%29"],
 ["(part._(.'(lib._xml/xml..scrbl).'._.'.Datatypes.'))", "../xml/index.html#%28part._.Datatypes%29"],
 ["(part._(.'(lib._xml/xml..scrbl).'._.'.Simple_.X-expression_.Path_.Queries.'))", "../xml/index.html#%28part._.Simple_.X-expression_.Path_.Queries%29"],
 ["(part._(.'(lib._xrepl/xrepl..scrbl).'._.'.Hacking_.X.R.E.P.L.'))", "../xrepl/index.html#%28part._.Hacking_.X.R.E.P.L%29"],
 ["(part._(.'(lib._xrepl/xrepl..scrbl).'._.'top.'))", "../xrepl/index.html"]];


function convert_all_links_2() {
   var elements = document.getElementsByClassName("Sq");
   for (var i = 0; i < elements.length; i++) {
     var elem = elements[i];
     var tag = elem.href.match(/tag=[^&]*/);
     
     if (tag) {
       var pos = bsearch(decodeURIComponent(tag[0].substring(4)),
                                   link_targets[2],
                                   0,
                                   link_targets[2].length);
       if (pos) {
         var p = link_targets[2][pos][1];
         if (link_target_prefix) {
           p = link_target_prefix + p;
         }
         elem.href = p;
       }
     }
  }
}
convert_all_links_2();
